Class: Shipeasy::Admin::Generated::ClaudeTriggerConfig
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Shipeasy::Admin::Generated::ClaudeTriggerConfig
- Defined in:
- lib/shipeasy_admin/models/claude_trigger_config.rb
Overview
Non-secret config for a Claude trigger.
Instance Attribute Summary collapse
-
#fire_text ⇒ Object
Optional default prompt sent on a manual fire / when no event text applies.
-
#routine_id ⇒ Object
The Claude Code routine id this connector fires (the id recorded at setup).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ClaudeTriggerConfig
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ClaudeTriggerConfig
Initializes the object
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/shipeasy_admin/models/claude_trigger_config.rb', line 59 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::ClaudeTriggerConfig` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::ClaudeTriggerConfig`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'routine_id') self.routine_id = attributes[:'routine_id'] else self.routine_id = nil end if attributes.key?(:'fire_text') self.fire_text = attributes[:'fire_text'] end end |
Instance Attribute Details
#fire_text ⇒ Object
Optional default prompt sent on a manual fire / when no event text applies.
23 24 25 |
# File 'lib/shipeasy_admin/models/claude_trigger_config.rb', line 23 def fire_text @fire_text end |
#routine_id ⇒ Object
The Claude Code routine id this connector fires (the id recorded at setup). Idempotency key for the connector.
20 21 22 |
# File 'lib/shipeasy_admin/models/claude_trigger_config.rb', line 20 def routine_id @routine_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
34 35 36 |
# File 'lib/shipeasy_admin/models/claude_trigger_config.rb', line 34 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
39 40 41 |
# File 'lib/shipeasy_admin/models/claude_trigger_config.rb', line 39 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 |
# File 'lib/shipeasy_admin/models/claude_trigger_config.rb', line 26 def self.attribute_map { :'routine_id' => :'routineId', :'fire_text' => :'fireText' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/shipeasy_admin/models/claude_trigger_config.rb', line 166 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
52 53 54 55 |
# File 'lib/shipeasy_admin/models/claude_trigger_config.rb', line 52 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 |
# File 'lib/shipeasy_admin/models/claude_trigger_config.rb', line 44 def self.openapi_types { :'routine_id' => :'String', :'fire_text' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
144 145 146 147 148 149 |
# File 'lib/shipeasy_admin/models/claude_trigger_config.rb', line 144 def ==(o) return true if self.equal?(o) self.class == o.class && routine_id == o.routine_id && fire_text == o.fire_text end |
#eql?(o) ⇒ Boolean
153 154 155 |
# File 'lib/shipeasy_admin/models/claude_trigger_config.rb', line 153 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
159 160 161 |
# File 'lib/shipeasy_admin/models/claude_trigger_config.rb', line 159 def hash [routine_id, fire_text].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/shipeasy_admin/models/claude_trigger_config.rb', line 86 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @routine_id.nil? invalid_properties.push('invalid value for "routine_id", routine_id cannot be nil.') end if @routine_id.to_s.length < 1 invalid_properties.push('invalid value for "routine_id", the character length must be greater than or equal to 1.') end if !@fire_text.nil? && @fire_text.to_s.length < 1 invalid_properties.push('invalid value for "fire_text", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/shipeasy_admin/models/claude_trigger_config.rb', line 188 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
106 107 108 109 110 111 112 |
# File 'lib/shipeasy_admin/models/claude_trigger_config.rb', line 106 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @routine_id.nil? return false if @routine_id.to_s.length < 1 return false if !@fire_text.nil? && @fire_text.to_s.length < 1 true end |