Class: Shipeasy::Admin::Generated::CopilotTriggerConfig
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Shipeasy::Admin::Generated::CopilotTriggerConfig
- Defined in:
- lib/shipeasy_admin/models/copilot_trigger_config.rb
Overview
Non-secret config for a Copilot trigger.
Instance Attribute Summary collapse
-
#base_ref ⇒ Object
Optional base ref the agent branches from.
-
#owner ⇒ Object
GitHub repo owner.
-
#project_id ⇒ Object
Shipeasy project id the run targets.
-
#repo ⇒ Object
GitHub repo name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CopilotTriggerConfig
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CopilotTriggerConfig
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/shipeasy_admin/models/copilot_trigger_config.rb', line 69 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::CopilotTriggerConfig` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::CopilotTriggerConfig`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'owner') self.owner = attributes[:'owner'] else self.owner = nil end if attributes.key?(:'repo') self.repo = attributes[:'repo'] else self.repo = nil end if attributes.key?(:'base_ref') self.base_ref = attributes[:'base_ref'] end if attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] else self.project_id = nil end end |
Instance Attribute Details
#base_ref ⇒ Object
Optional base ref the agent branches from.
26 27 28 |
# File 'lib/shipeasy_admin/models/copilot_trigger_config.rb', line 26 def base_ref @base_ref end |
#owner ⇒ Object
GitHub repo owner. Together with repo forms the connector's idempotency key (owner/repo).
20 21 22 |
# File 'lib/shipeasy_admin/models/copilot_trigger_config.rb', line 20 def owner @owner end |
#project_id ⇒ Object
Shipeasy project id the run targets.
29 30 31 |
# File 'lib/shipeasy_admin/models/copilot_trigger_config.rb', line 29 def project_id @project_id end |
#repo ⇒ Object
GitHub repo name.
23 24 25 |
# File 'lib/shipeasy_admin/models/copilot_trigger_config.rb', line 23 def repo @repo end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
42 43 44 |
# File 'lib/shipeasy_admin/models/copilot_trigger_config.rb', line 42 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
47 48 49 |
# File 'lib/shipeasy_admin/models/copilot_trigger_config.rb', line 47 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 |
# File 'lib/shipeasy_admin/models/copilot_trigger_config.rb', line 32 def self.attribute_map { :'owner' => :'owner', :'repo' => :'repo', :'base_ref' => :'baseRef', :'project_id' => :'projectId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/shipeasy_admin/models/copilot_trigger_config.rb', line 238 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
62 63 64 65 |
# File 'lib/shipeasy_admin/models/copilot_trigger_config.rb', line 62 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
52 53 54 55 56 57 58 59 |
# File 'lib/shipeasy_admin/models/copilot_trigger_config.rb', line 52 def self.openapi_types { :'owner' => :'String', :'repo' => :'String', :'base_ref' => :'String', :'project_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
214 215 216 217 218 219 220 221 |
# File 'lib/shipeasy_admin/models/copilot_trigger_config.rb', line 214 def ==(o) return true if self.equal?(o) self.class == o.class && owner == o.owner && repo == o.repo && base_ref == o.base_ref && project_id == o.project_id end |
#eql?(o) ⇒ Boolean
225 226 227 |
# File 'lib/shipeasy_admin/models/copilot_trigger_config.rb', line 225 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
231 232 233 |
# File 'lib/shipeasy_admin/models/copilot_trigger_config.rb', line 231 def hash [owner, repo, base_ref, project_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/shipeasy_admin/models/copilot_trigger_config.rb', line 108 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @owner.nil? invalid_properties.push('invalid value for "owner", owner cannot be nil.') end if @owner.to_s.length < 1 invalid_properties.push('invalid value for "owner", the character length must be greater than or equal to 1.') end if @repo.nil? invalid_properties.push('invalid value for "repo", repo cannot be nil.') end if @repo.to_s.length < 1 invalid_properties.push('invalid value for "repo", the character length must be greater than or equal to 1.') end if !@base_ref.nil? && @base_ref.to_s.length < 1 invalid_properties.push('invalid value for "base_ref", the character length must be greater than or equal to 1.') end if @project_id.nil? invalid_properties.push('invalid value for "project_id", project_id cannot be nil.') end if @project_id.to_s.length < 1 invalid_properties.push('invalid value for "project_id", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/shipeasy_admin/models/copilot_trigger_config.rb', line 260 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/shipeasy_admin/models/copilot_trigger_config.rb', line 144 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @owner.nil? return false if @owner.to_s.length < 1 return false if @repo.nil? return false if @repo.to_s.length < 1 return false if !@base_ref.nil? && @base_ref.to_s.length < 1 return false if @project_id.nil? return false if @project_id.to_s.length < 1 true end |