Class: Shipeasy::Admin::Generated::CreateClaudeTriggerRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Shipeasy::Admin::Generated::CreateClaudeTriggerRequest
- Defined in:
- lib/shipeasy_admin/models/create_claude_trigger_request.rb
Overview
Create a Claude Code routine trigger in one shot. Idempotent by config.routineId — re-creating with the same routine id updates the existing row.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#config ⇒ Object
Returns the value of attribute config.
-
#enabled ⇒ Object
Whether the trigger is active on create.
-
#events ⇒ Object
Events that auto-fire the routine.
-
#name ⇒ Object
Human-readable connector label.
-
#provider ⇒ Object
Discriminator.
-
#token ⇒ Object
The routine's fire bearer token (secret).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateClaudeTriggerRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateClaudeTriggerRequest
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/shipeasy_admin/models/create_claude_trigger_request.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::CreateClaudeTriggerRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::CreateClaudeTriggerRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'provider') self.provider = attributes[:'provider'] else self.provider = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = 'Claude trigger' end if attributes.key?(:'events') if (value = attributes[:'events']).is_a?(Array) self.events = value end end if attributes.key?(:'config') self.config = attributes[:'config'] else self.config = nil end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'enabled') self.enabled = attributes[:'enabled'] else self.enabled = true end end |
Instance Attribute Details
#config ⇒ Object
Returns the value of attribute config.
28 29 30 |
# File 'lib/shipeasy_admin/models/create_claude_trigger_request.rb', line 28 def config @config end |
#enabled ⇒ Object
Whether the trigger is active on create.
34 35 36 |
# File 'lib/shipeasy_admin/models/create_claude_trigger_request.rb', line 34 def enabled @enabled end |
#events ⇒ Object
Events that auto-fire the routine. Defaults to empty so the trigger does not auto-fire paid runs until events are subscribed.
26 27 28 |
# File 'lib/shipeasy_admin/models/create_claude_trigger_request.rb', line 26 def events @events end |
#name ⇒ Object
Human-readable connector label.
23 24 25 |
# File 'lib/shipeasy_admin/models/create_claude_trigger_request.rb', line 23 def name @name end |
#provider ⇒ Object
Discriminator. Claude Code scheduled-routine trigger.
20 21 22 |
# File 'lib/shipeasy_admin/models/create_claude_trigger_request.rb', line 20 def provider @provider end |
#token ⇒ Object
The routine's fire bearer token (secret). Optional — a tokenless trigger is recorded but not fireable until a token is added later. Encrypted into the credentials cipher; never persisted in config or returned.
31 32 33 |
# File 'lib/shipeasy_admin/models/create_claude_trigger_request.rb', line 31 def token @token end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
71 72 73 |
# File 'lib/shipeasy_admin/models/create_claude_trigger_request.rb', line 71 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/shipeasy_admin/models/create_claude_trigger_request.rb', line 76 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/shipeasy_admin/models/create_claude_trigger_request.rb', line 59 def self.attribute_map { :'provider' => :'provider', :'name' => :'name', :'events' => :'events', :'config' => :'config', :'token' => :'token', :'enabled' => :'enabled' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/shipeasy_admin/models/create_claude_trigger_request.rb', line 271 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
93 94 95 96 |
# File 'lib/shipeasy_admin/models/create_claude_trigger_request.rb', line 93 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 |
# File 'lib/shipeasy_admin/models/create_claude_trigger_request.rb', line 81 def self.openapi_types { :'provider' => :'String', :'name' => :'String', :'events' => :'Array<ConnectorEvent>', :'config' => :'ClaudeTriggerConfig', :'token' => :'String', :'enabled' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
245 246 247 248 249 250 251 252 253 254 |
# File 'lib/shipeasy_admin/models/create_claude_trigger_request.rb', line 245 def ==(o) return true if self.equal?(o) self.class == o.class && provider == o.provider && name == o.name && events == o.events && config == o.config && token == o.token && enabled == o.enabled end |
#eql?(o) ⇒ Boolean
258 259 260 |
# File 'lib/shipeasy_admin/models/create_claude_trigger_request.rb', line 258 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
264 265 266 |
# File 'lib/shipeasy_admin/models/create_claude_trigger_request.rb', line 264 def hash [provider, name, events, config, token, enabled].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/shipeasy_admin/models/create_claude_trigger_request.rb', line 151 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @provider.nil? invalid_properties.push('invalid value for "provider", provider cannot be nil.') end if !@name.nil? && @name.to_s.length > 80 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 80.') end if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if @config.nil? invalid_properties.push('invalid value for "config", config cannot be nil.') end if !@token.nil? && @token.to_s.length < 1 invalid_properties.push('invalid value for "token", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/shipeasy_admin/models/create_claude_trigger_request.rb', line 293 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/shipeasy_admin/models/create_claude_trigger_request.rb', line 179 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @provider.nil? provider_validator = EnumAttributeValidator.new('String', ["claude_trigger"]) return false unless provider_validator.valid?(@provider) return false if !@name.nil? && @name.to_s.length > 80 return false if !@name.nil? && @name.to_s.length < 1 return false if @config.nil? return false if !@token.nil? && @token.to_s.length < 1 true end |