Class: Shipeasy::Admin::Generated::CreateConfigRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/shipeasy_admin/models/create_config_request.rb

Overview

Body for POST /api/admin/configs. name + schema required.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateConfigRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/shipeasy_admin/models/create_config_request.rb', line 75

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::CreateConfigRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::CreateConfigRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'folder')
    self.folder = attributes[:'folder']
  end

  if attributes.key?(:'schema')
    if (value = attributes[:'schema']).is_a?(Hash)
      self.schema = value
    end
  else
    self.schema = nil
  end

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  end
end

Instance Attribute Details

#descriptionObject

Optional free-form description shown in the dashboard. Max 512 chars.



23
24
25
# File 'lib/shipeasy_admin/models/create_config_request.rb', line 23

def description
  @description
end

#folderObject

Optional folder name grouping items in the dashboard. Alphanumeric, _ or - (no /). Part of the SDK lookup key (<folder>/<name>).



26
27
28
# File 'lib/shipeasy_admin/models/create_config_request.rb', line 26

def folder
  @folder
end

#nameObject

Stable config/killswitch key in folder.name form (two lowercase segments separated by a dot, e.g. pricing.tiers). Immutable after create.



20
21
22
# File 'lib/shipeasy_admin/models/create_config_request.rb', line 20

def name
  @name
end

#schemaObject

JSON Schema (draft 2020-12) describing the shape of the config value. Top-level type must be 'object'; every published value is validated against this schema.



29
30
31
# File 'lib/shipeasy_admin/models/create_config_request.rb', line 29

def schema
  @schema
end

#valueObject

Returns the value of attribute value.



31
32
33
# File 'lib/shipeasy_admin/models/create_config_request.rb', line 31

def value
  @value
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/shipeasy_admin/models/create_config_request.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/shipeasy_admin/models/create_config_request.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
# File 'lib/shipeasy_admin/models/create_config_request.rb', line 34

def self.attribute_map
  {
    :'name' => :'name',
    :'description' => :'description',
    :'folder' => :'folder',
    :'schema' => :'schema',
    :'value' => :'value'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/shipeasy_admin/models/create_config_request.rb', line 253

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
70
71
# File 'lib/shipeasy_admin/models/create_config_request.rb', line 66

def self.openapi_nullable
  Set.new([
    :'folder',
    :'value'
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
# File 'lib/shipeasy_admin/models/create_config_request.rb', line 55

def self.openapi_types
  {
    :'name' => :'String',
    :'description' => :'String',
    :'folder' => :'String',
    :'schema' => :'Hash<String, Object>',
    :'value' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



228
229
230
231
232
233
234
235
236
# File 'lib/shipeasy_admin/models/create_config_request.rb', line 228

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      description == o.description &&
      folder == o.folder &&
      schema == o.schema &&
      value == o.value
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


240
241
242
# File 'lib/shipeasy_admin/models/create_config_request.rb', line 240

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



246
247
248
# File 'lib/shipeasy_admin/models/create_config_request.rb', line 246

def hash
  [name, description, folder, schema, value].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/shipeasy_admin/models/create_config_request.rb', line 118

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 128
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 128.')
  end

  pattern = Regexp.new(/^(?:_default|[a-z0-9](?:[a-z0-9_-]*[a-z0-9])?)\.[a-z0-9](?:[a-z0-9_-]*[a-z0-9])?$/)
  if @name !~ pattern
    invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.")
  end

  if !@description.nil? && @description.to_s.length > 512
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 512.')
  end

  if !@folder.nil? && @folder.to_s.length > 256
    invalid_properties.push('invalid value for "folder", the character length must be smaller than or equal to 256.')
  end

  pattern = Regexp.new(/^[a-zA-Z0-9_-]+$/)
  if !@folder.nil? && @folder !~ pattern
    invalid_properties.push("invalid value for \"folder\", must conform to the pattern #{pattern}.")
  end

  if @schema.nil?
    invalid_properties.push('invalid value for "schema", schema cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/shipeasy_admin/models/create_config_request.rb', line 275

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



156
157
158
159
160
161
162
163
164
165
166
# File 'lib/shipeasy_admin/models/create_config_request.rb', line 156

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length > 128
  return false if @name !~ Regexp.new(/^(?:_default|[a-z0-9](?:[a-z0-9_-]*[a-z0-9])?)\.[a-z0-9](?:[a-z0-9_-]*[a-z0-9])?$/)
  return false if !@description.nil? && @description.to_s.length > 512
  return false if !@folder.nil? && @folder.to_s.length > 256
  return false if !@folder.nil? && @folder !~ Regexp.new(/^[a-zA-Z0-9_-]+$/)
  return false if @schema.nil?
  true
end