Class: Shipeasy::Admin::Generated::CreateCopilotTriggerRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/shipeasy_admin/models/create_copilot_trigger_request.rb

Overview

Create a GitHub Copilot coding-agent trigger. Idempotent by config.owner/config.repo.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateCopilotTriggerRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/shipeasy_admin/models/create_copilot_trigger_request.rb', line 100

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::CreateCopilotTriggerRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::CreateCopilotTriggerRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'provider')
    self.provider = attributes[:'provider']
  else
    self.provider = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = 'Copilot trigger'
  end

  if attributes.key?(:'events')
    if (value = attributes[:'events']).is_a?(Array)
      self.events = value
    end
  end

  if attributes.key?(:'config')
    self.config = attributes[:'config']
  else
    self.config = nil
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  else
    self.token = nil
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  else
    self.enabled = true
  end
end

Instance Attribute Details

#configObject

Returns the value of attribute config.



28
29
30
# File 'lib/shipeasy_admin/models/create_copilot_trigger_request.rb', line 28

def config
  @config
end

#enabledObject

Whether the trigger is active on create.



34
35
36
# File 'lib/shipeasy_admin/models/create_copilot_trigger_request.rb', line 34

def enabled
  @enabled
end

#eventsObject

Events that auto-fire a Copilot agent task. Defaults to empty.



26
27
28
# File 'lib/shipeasy_admin/models/create_copilot_trigger_request.rb', line 26

def events
  @events
end

#nameObject

Human-readable connector label.



23
24
25
# File 'lib/shipeasy_admin/models/create_copilot_trigger_request.rb', line 23

def name
  @name
end

#providerObject

Discriminator. GitHub Copilot coding-agent trigger.



20
21
22
# File 'lib/shipeasy_admin/models/create_copilot_trigger_request.rb', line 20

def provider
  @provider
end

#tokenObject

Copilot-licensed user PAT (secret). The ops key lives in the repo's GitHub "Agents" secret store and is never sent through Shipeasy. Encrypted; never returned.



31
32
33
# File 'lib/shipeasy_admin/models/create_copilot_trigger_request.rb', line 31

def token
  @token
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/shipeasy_admin/models/create_copilot_trigger_request.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/shipeasy_admin/models/create_copilot_trigger_request.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
# File 'lib/shipeasy_admin/models/create_copilot_trigger_request.rb', line 59

def self.attribute_map
  {
    :'provider' => :'provider',
    :'name' => :'name',
    :'events' => :'events',
    :'config' => :'config',
    :'token' => :'token',
    :'enabled' => :'enabled'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
# File 'lib/shipeasy_admin/models/create_copilot_trigger_request.rb', line 278

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



93
94
95
96
# File 'lib/shipeasy_admin/models/create_copilot_trigger_request.rb', line 93

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
# File 'lib/shipeasy_admin/models/create_copilot_trigger_request.rb', line 81

def self.openapi_types
  {
    :'provider' => :'String',
    :'name' => :'String',
    :'events' => :'Array<ConnectorEvent>',
    :'config' => :'CopilotTriggerConfig',
    :'token' => :'String',
    :'enabled' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



252
253
254
255
256
257
258
259
260
261
# File 'lib/shipeasy_admin/models/create_copilot_trigger_request.rb', line 252

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      provider == o.provider &&
      name == o.name &&
      events == o.events &&
      config == o.config &&
      token == o.token &&
      enabled == o.enabled
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


265
266
267
# File 'lib/shipeasy_admin/models/create_copilot_trigger_request.rb', line 265

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



271
272
273
# File 'lib/shipeasy_admin/models/create_copilot_trigger_request.rb', line 271

def hash
  [provider, name, events, config, token, enabled].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/shipeasy_admin/models/create_copilot_trigger_request.rb', line 153

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @provider.nil?
    invalid_properties.push('invalid value for "provider", provider cannot be nil.')
  end

  if !@name.nil? && @name.to_s.length > 80
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 80.')
  end

  if !@name.nil? && @name.to_s.length < 1
    invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.')
  end

  if @config.nil?
    invalid_properties.push('invalid value for "config", config cannot be nil.')
  end

  if @token.nil?
    invalid_properties.push('invalid value for "token", token cannot be nil.')
  end

  if @token.to_s.length < 1
    invalid_properties.push('invalid value for "token", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/shipeasy_admin/models/create_copilot_trigger_request.rb', line 300

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/shipeasy_admin/models/create_copilot_trigger_request.rb', line 185

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @provider.nil?
  provider_validator = EnumAttributeValidator.new('String', ["copilot_trigger"])
  return false unless provider_validator.valid?(@provider)
  return false if !@name.nil? && @name.to_s.length > 80
  return false if !@name.nil? && @name.to_s.length < 1
  return false if @config.nil?
  return false if @token.nil?
  return false if @token.to_s.length < 1
  true
end