Class: Shipeasy::Admin::Generated::CreateJulesTriggerRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Shipeasy::Admin::Generated::CreateJulesTriggerRequest
- Defined in:
- lib/shipeasy_admin/models/create_jules_trigger_request.rb
Overview
Create a Google Jules trigger. Both keys are required up front. Idempotent by config.source.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#api_key ⇒ Object
Jules API key that launches the session (secret).
-
#config ⇒ Object
Returns the value of attribute config.
-
#enabled ⇒ Object
Whether the trigger is active on create.
-
#events ⇒ Object
Events that auto-fire a Jules session.
-
#name ⇒ Object
Human-readable connector label.
-
#ops_key ⇒ Object
Restricted Shipeasy ops key, embedded in the prompt (Jules exposes no env channel) (secret).
-
#provider ⇒ Object
Discriminator.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateJulesTriggerRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateJulesTriggerRequest
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/shipeasy_admin/models/create_jules_trigger_request.rb', line 105 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::CreateJulesTriggerRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::CreateJulesTriggerRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'provider') self.provider = attributes[:'provider'] else self.provider = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = 'Jules trigger' end if attributes.key?(:'events') if (value = attributes[:'events']).is_a?(Array) self.events = value end end if attributes.key?(:'config') self.config = attributes[:'config'] else self.config = nil end if attributes.key?(:'api_key') self.api_key = attributes[:'api_key'] else self.api_key = nil end if attributes.key?(:'ops_key') self.ops_key = attributes[:'ops_key'] else self.ops_key = nil end if attributes.key?(:'enabled') self.enabled = attributes[:'enabled'] else self.enabled = true end end |
Instance Attribute Details
#api_key ⇒ Object
Jules API key that launches the session (secret). Encrypted into the credentials cipher; never returned.
31 32 33 |
# File 'lib/shipeasy_admin/models/create_jules_trigger_request.rb', line 31 def api_key @api_key end |
#config ⇒ Object
Returns the value of attribute config.
28 29 30 |
# File 'lib/shipeasy_admin/models/create_jules_trigger_request.rb', line 28 def config @config end |
#enabled ⇒ Object
Whether the trigger is active on create.
37 38 39 |
# File 'lib/shipeasy_admin/models/create_jules_trigger_request.rb', line 37 def enabled @enabled end |
#events ⇒ Object
Events that auto-fire a Jules session. Defaults to empty.
26 27 28 |
# File 'lib/shipeasy_admin/models/create_jules_trigger_request.rb', line 26 def events @events end |
#name ⇒ Object
Human-readable connector label.
23 24 25 |
# File 'lib/shipeasy_admin/models/create_jules_trigger_request.rb', line 23 def name @name end |
#ops_key ⇒ Object
Restricted Shipeasy ops key, embedded in the prompt (Jules exposes no env channel) (secret). Encrypted; never returned.
34 35 36 |
# File 'lib/shipeasy_admin/models/create_jules_trigger_request.rb', line 34 def ops_key @ops_key end |
#provider ⇒ Object
Discriminator. Google Jules trigger.
20 21 22 |
# File 'lib/shipeasy_admin/models/create_jules_trigger_request.rb', line 20 def provider @provider end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
75 76 77 |
# File 'lib/shipeasy_admin/models/create_jules_trigger_request.rb', line 75 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
80 81 82 |
# File 'lib/shipeasy_admin/models/create_jules_trigger_request.rb', line 80 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/shipeasy_admin/models/create_jules_trigger_request.rb', line 62 def self.attribute_map { :'provider' => :'provider', :'name' => :'name', :'events' => :'events', :'config' => :'config', :'api_key' => :'apiKey', :'ops_key' => :'opsKey', :'enabled' => :'enabled' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 |
# File 'lib/shipeasy_admin/models/create_jules_trigger_request.rb', line 314 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
98 99 100 101 |
# File 'lib/shipeasy_admin/models/create_jules_trigger_request.rb', line 98 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/shipeasy_admin/models/create_jules_trigger_request.rb', line 85 def self.openapi_types { :'provider' => :'String', :'name' => :'String', :'events' => :'Array<ConnectorEvent>', :'config' => :'JulesTriggerConfig', :'api_key' => :'String', :'ops_key' => :'String', :'enabled' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/shipeasy_admin/models/create_jules_trigger_request.rb', line 287 def ==(o) return true if self.equal?(o) self.class == o.class && provider == o.provider && name == o.name && events == o.events && config == o.config && api_key == o.api_key && ops_key == o.ops_key && enabled == o.enabled end |
#eql?(o) ⇒ Boolean
301 302 303 |
# File 'lib/shipeasy_admin/models/create_jules_trigger_request.rb', line 301 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
307 308 309 |
# File 'lib/shipeasy_admin/models/create_jules_trigger_request.rb', line 307 def hash [provider, name, events, config, api_key, ops_key, enabled].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/shipeasy_admin/models/create_jules_trigger_request.rb', line 164 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @provider.nil? invalid_properties.push('invalid value for "provider", provider cannot be nil.') end if !@name.nil? && @name.to_s.length > 80 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 80.') end if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if @config.nil? invalid_properties.push('invalid value for "config", config cannot be nil.') end if @api_key.nil? invalid_properties.push('invalid value for "api_key", api_key cannot be nil.') end if @api_key.to_s.length < 1 invalid_properties.push('invalid value for "api_key", the character length must be greater than or equal to 1.') end if @ops_key.nil? invalid_properties.push('invalid value for "ops_key", ops_key cannot be nil.') end if @ops_key.to_s.length < 1 invalid_properties.push('invalid value for "ops_key", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/shipeasy_admin/models/create_jules_trigger_request.rb', line 336 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/shipeasy_admin/models/create_jules_trigger_request.rb', line 204 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @provider.nil? provider_validator = EnumAttributeValidator.new('String', ["jules_trigger"]) return false unless provider_validator.valid?(@provider) return false if !@name.nil? && @name.to_s.length > 80 return false if !@name.nil? && @name.to_s.length < 1 return false if @config.nil? return false if @api_key.nil? return false if @api_key.to_s.length < 1 return false if @ops_key.nil? return false if @ops_key.to_s.length < 1 true end |