Class: Shipeasy::Admin::Generated::CreateKillswitchRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/shipeasy_admin/models/create_killswitch_request.rb

Overview

Body for POST /api/admin/killswitches. Only name is required.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateKillswitchRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/shipeasy_admin/models/create_killswitch_request.rb', line 75

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::CreateKillswitchRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::CreateKillswitchRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'folder')
    self.folder = attributes[:'folder']
  end

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  end

  if attributes.key?(:'switches')
    if (value = attributes[:'switches']).is_a?(Hash)
      self.switches = value
    end
  end
end

Instance Attribute Details

#descriptionObject

Optional free-form description shown in the dashboard. Max 512 chars.



23
24
25
# File 'lib/shipeasy_admin/models/create_killswitch_request.rb', line 23

def description
  @description
end

#folderObject

Optional folder name grouping items in the dashboard. Alphanumeric, _ or - (no /). Part of the SDK lookup key (<folder>/<name>).



26
27
28
# File 'lib/shipeasy_admin/models/create_killswitch_request.rb', line 26

def folder
  @folder
end

#nameObject

Stable config/killswitch key in folder.name form (two lowercase segments separated by a dot, e.g. pricing.tiers). Immutable after create.



20
21
22
# File 'lib/shipeasy_admin/models/create_killswitch_request.rb', line 20

def name
  @name
end

#switchesObject

Initial per-switch overrides applied to every env. Empty/omitted leaves the killswitch with only the flat value.



32
33
34
# File 'lib/shipeasy_admin/models/create_killswitch_request.rb', line 32

def switches
  @switches
end

#valueObject

Default value applied to every env at creation. Defaults to false. Use true to ship the killswitch pre-tripped.



29
30
31
# File 'lib/shipeasy_admin/models/create_killswitch_request.rb', line 29

def value
  @value
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



46
47
48
# File 'lib/shipeasy_admin/models/create_killswitch_request.rb', line 46

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/shipeasy_admin/models/create_killswitch_request.rb', line 51

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
# File 'lib/shipeasy_admin/models/create_killswitch_request.rb', line 35

def self.attribute_map
  {
    :'name' => :'name',
    :'description' => :'description',
    :'folder' => :'folder',
    :'value' => :'value',
    :'switches' => :'switches'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/shipeasy_admin/models/create_killswitch_request.rb', line 236

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



67
68
69
70
71
# File 'lib/shipeasy_admin/models/create_killswitch_request.rb', line 67

def self.openapi_nullable
  Set.new([
    :'folder',
  ])
end

.openapi_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
# File 'lib/shipeasy_admin/models/create_killswitch_request.rb', line 56

def self.openapi_types
  {
    :'name' => :'String',
    :'description' => :'String',
    :'folder' => :'String',
    :'value' => :'Boolean',
    :'switches' => :'Hash<String, Boolean>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



211
212
213
214
215
216
217
218
219
# File 'lib/shipeasy_admin/models/create_killswitch_request.rb', line 211

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      description == o.description &&
      folder == o.folder &&
      value == o.value &&
      switches == o.switches
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


223
224
225
# File 'lib/shipeasy_admin/models/create_killswitch_request.rb', line 223

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



229
230
231
# File 'lib/shipeasy_admin/models/create_killswitch_request.rb', line 229

def hash
  [name, description, folder, value, switches].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/shipeasy_admin/models/create_killswitch_request.rb', line 116

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 128
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 128.')
  end

  pattern = Regexp.new(/^(?:_default|[a-z0-9](?:[a-z0-9_-]*[a-z0-9])?)\.[a-z0-9](?:[a-z0-9_-]*[a-z0-9])?$/)
  if @name !~ pattern
    invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.")
  end

  if !@description.nil? && @description.to_s.length > 512
    invalid_properties.push('invalid value for "description", the character length must be smaller than or equal to 512.')
  end

  if !@folder.nil? && @folder.to_s.length > 256
    invalid_properties.push('invalid value for "folder", the character length must be smaller than or equal to 256.')
  end

  pattern = Regexp.new(/^[a-zA-Z0-9_-]+$/)
  if !@folder.nil? && @folder !~ pattern
    invalid_properties.push("invalid value for \"folder\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/shipeasy_admin/models/create_killswitch_request.rb', line 258

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



150
151
152
153
154
155
156
157
158
159
# File 'lib/shipeasy_admin/models/create_killswitch_request.rb', line 150

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @name.to_s.length > 128
  return false if @name !~ Regexp.new(/^(?:_default|[a-z0-9](?:[a-z0-9_-]*[a-z0-9])?)\.[a-z0-9](?:[a-z0-9_-]*[a-z0-9])?$/)
  return false if !@description.nil? && @description.to_s.length > 512
  return false if !@folder.nil? && @folder.to_s.length > 256
  return false if !@folder.nil? && @folder !~ Regexp.new(/^[a-zA-Z0-9_-]+$/)
  true
end