Class: Shipeasy::Admin::Generated::CreateOpsItemRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/shipeasy_admin/models/create_ops_item_request.rb

Overview

Body for POST /api/admin/ops. Files one queue item; type selects bug vs. feature request.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateOpsItemRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/shipeasy_admin/models/create_ops_item_request.rb', line 101

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::CreateOpsItemRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::CreateOpsItemRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'body')
    self.body = attributes[:'body']
  end

  if attributes.key?(:'priority')
    self.priority = attributes[:'priority']
  end

  if attributes.key?(:'steps_to_reproduce')
    self.steps_to_reproduce = attributes[:'steps_to_reproduce']
  end

  if attributes.key?(:'page_url')
    self.page_url = attributes[:'page_url']
  end
end

Instance Attribute Details

#bodyObject

Detailed description / steps to reproduce.



26
27
28
# File 'lib/shipeasy_admin/models/create_ops_item_request.rb', line 26

def body
  @body
end

#page_urlObject

URL of the page the item relates to.



35
36
37
# File 'lib/shipeasy_admin/models/create_ops_item_request.rb', line 35

def page_url
  @page_url
end

#priorityObject

Initial triage priority.



29
30
31
# File 'lib/shipeasy_admin/models/create_ops_item_request.rb', line 29

def priority
  @priority
end

#steps_to_reproduceObject

Reproduction steps (bugs).



32
33
34
# File 'lib/shipeasy_admin/models/create_ops_item_request.rb', line 32

def steps_to_reproduce
  @steps_to_reproduce
end

#titleObject

One-line title of the bug or feature request.



23
24
25
# File 'lib/shipeasy_admin/models/create_ops_item_request.rb', line 23

def title
  @title
end

#typeObject

Item type to file. Only the two user-fileable types are accepted here — error and alert tickets are auto-filed by the platform and cannot be created over the API.



20
21
22
# File 'lib/shipeasy_admin/models/create_ops_item_request.rb', line 20

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



72
73
74
# File 'lib/shipeasy_admin/models/create_ops_item_request.rb', line 72

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



77
78
79
# File 'lib/shipeasy_admin/models/create_ops_item_request.rb', line 77

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



60
61
62
63
64
65
66
67
68
69
# File 'lib/shipeasy_admin/models/create_ops_item_request.rb', line 60

def self.attribute_map
  {
    :'type' => :'type',
    :'title' => :'title',
    :'body' => :'body',
    :'priority' => :'priority',
    :'steps_to_reproduce' => :'stepsToReproduce',
    :'page_url' => :'pageUrl'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/shipeasy_admin/models/create_ops_item_request.rb', line 249

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



94
95
96
97
# File 'lib/shipeasy_admin/models/create_ops_item_request.rb', line 94

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
# File 'lib/shipeasy_admin/models/create_ops_item_request.rb', line 82

def self.openapi_types
  {
    :'type' => :'String',
    :'title' => :'String',
    :'body' => :'String',
    :'priority' => :'String',
    :'steps_to_reproduce' => :'String',
    :'page_url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



223
224
225
226
227
228
229
230
231
232
# File 'lib/shipeasy_admin/models/create_ops_item_request.rb', line 223

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      title == o.title &&
      body == o.body &&
      priority == o.priority &&
      steps_to_reproduce == o.steps_to_reproduce &&
      page_url == o.page_url
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


236
237
238
# File 'lib/shipeasy_admin/models/create_ops_item_request.rb', line 236

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



242
243
244
# File 'lib/shipeasy_admin/models/create_ops_item_request.rb', line 242

def hash
  [type, title, body, priority, steps_to_reproduce, page_url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/shipeasy_admin/models/create_ops_item_request.rb', line 146

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  if @title.to_s.length > 200
    invalid_properties.push('invalid value for "title", the character length must be smaller than or equal to 200.')
  end

  if @title.to_s.length < 1
    invalid_properties.push('invalid value for "title", the character length must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/shipeasy_admin/models/create_ops_item_request.rb', line 271

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/shipeasy_admin/models/create_ops_item_request.rb', line 170

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["bug", "feature_request"])
  return false unless type_validator.valid?(@type)
  return false if @title.nil?
  return false if @title.to_s.length > 200
  return false if @title.to_s.length < 1
  priority_validator = EnumAttributeValidator.new('String', ["nice_to_have", "medium", "high", "critical"])
  return false unless priority_validator.valid?(@priority)
  true
end