Class: Shipeasy::Admin::Generated::DraftsApi
- Inherits:
-
Object
- Object
- Shipeasy::Admin::Generated::DraftsApi
- Defined in:
- lib/shipeasy_admin/api/drafts_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ DraftsApi
constructor
A new instance of DraftsApi.
-
#list_i18n_drafts(opts = {}) ⇒ Array<ListI18nDraftsResponseInner>
List translation drafts List staged translation drafts awaiting review/publish.
-
#list_i18n_drafts_with_http_info(opts = {}) ⇒ Array<(Array<ListI18nDraftsResponseInner>, Integer, Hash)>
List translation drafts List staged translation drafts awaiting review/publish.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/shipeasy_admin/api/drafts_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#list_i18n_drafts(opts = {}) ⇒ Array<ListI18nDraftsResponseInner>
List translation drafts List staged translation drafts awaiting review/publish. Use case: Review machine-translation drafts before publishing them to a locale.
27 28 29 30 |
# File 'lib/shipeasy_admin/api/drafts_api.rb', line 27 def list_i18n_drafts(opts = {}) data, _status_code, _headers = list_i18n_drafts_with_http_info(opts) data end |
#list_i18n_drafts_with_http_info(opts = {}) ⇒ Array<(Array<ListI18nDraftsResponseInner>, Integer, Hash)>
List translation drafts List staged translation drafts awaiting review/publish. Use case: Review machine-translation drafts before publishing them to a locale.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/shipeasy_admin/api/drafts_api.rb', line 37 def list_i18n_drafts_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DraftsApi.list_i18n_drafts ...' end # resource path local_var_path = '/api/admin/i18n/drafts' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Project-Id'] = opts[:'x_project_id'] if !opts[:'x_project_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<ListI18nDraftsResponseInner>' # auth_names auth_names = opts[:debug_auth_names] || ['bearerSdkKey'] = opts.merge( :operation => :"DraftsApi.list_i18n_drafts", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DraftsApi#list_i18n_drafts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |