Class: Shipeasy::Admin::Generated::ErrorSeriesRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/shipeasy_admin/models/error_series_request.rb

Overview

Time window for the occurrence series. Bounds are epoch seconds (Analytics Engine stores the occurrence timestamp in seconds). to must be strictly greater than from.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ErrorSeriesRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/shipeasy_admin/models/error_series_request.rb', line 64

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::ErrorSeriesRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::ErrorSeriesRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'from')
    self.from = attributes[:'from']
  else
    self.from = nil
  end

  if attributes.key?(:'to')
    self.to = attributes[:'to']
  else
    self.to = nil
  end

  if attributes.key?(:'bucket')
    self.bucket = attributes[:'bucket']
  else
    self.bucket = 3600
  end
end

Instance Attribute Details

#bucketObject

Bucket width in seconds (60s–86400s/1d). Defaults to 3600 (hourly). Each returned point is floor-aligned to this width.



26
27
28
# File 'lib/shipeasy_admin/models/error_series_request.rb', line 26

def bucket
  @bucket
end

#fromObject

Window start, epoch seconds (inclusive).



20
21
22
# File 'lib/shipeasy_admin/models/error_series_request.rb', line 20

def from
  @from
end

#toObject

Window end, epoch seconds (exclusive). Must be greater than from.



23
24
25
# File 'lib/shipeasy_admin/models/error_series_request.rb', line 23

def to
  @to
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



38
39
40
# File 'lib/shipeasy_admin/models/error_series_request.rb', line 38

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



43
44
45
# File 'lib/shipeasy_admin/models/error_series_request.rb', line 43

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
# File 'lib/shipeasy_admin/models/error_series_request.rb', line 29

def self.attribute_map
  {
    :'from' => :'from',
    :'to' => :'to',
    :'bucket' => :'bucket'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/shipeasy_admin/models/error_series_request.rb', line 213

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



57
58
59
60
# File 'lib/shipeasy_admin/models/error_series_request.rb', line 57

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
# File 'lib/shipeasy_admin/models/error_series_request.rb', line 48

def self.openapi_types
  {
    :'from' => :'Integer',
    :'to' => :'Integer',
    :'bucket' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



190
191
192
193
194
195
196
# File 'lib/shipeasy_admin/models/error_series_request.rb', line 190

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      from == o.from &&
      to == o.to &&
      bucket == o.bucket
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


200
201
202
# File 'lib/shipeasy_admin/models/error_series_request.rb', line 200

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



206
207
208
# File 'lib/shipeasy_admin/models/error_series_request.rb', line 206

def hash
  [from, to, bucket].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/shipeasy_admin/models/error_series_request.rb', line 99

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @from.nil?
    invalid_properties.push('invalid value for "from", from cannot be nil.')
  end

  if @from < 0
    invalid_properties.push('invalid value for "from", must be greater than or equal to 0.')
  end

  if @to.nil?
    invalid_properties.push('invalid value for "to", to cannot be nil.')
  end

  if @to < 0
    invalid_properties.push('invalid value for "to", must be greater than or equal to 0.')
  end

  if !@bucket.nil? && @bucket > 86400
    invalid_properties.push('invalid value for "bucket", must be smaller than or equal to 86400.')
  end

  if !@bucket.nil? && @bucket < 60
    invalid_properties.push('invalid value for "bucket", must be greater than or equal to 60.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/shipeasy_admin/models/error_series_request.rb', line 235

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



131
132
133
134
135
136
137
138
139
140
# File 'lib/shipeasy_admin/models/error_series_request.rb', line 131

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @from.nil?
  return false if @from < 0
  return false if @to.nil?
  return false if @to < 0
  return false if !@bucket.nil? && @bucket > 86400
  return false if !@bucket.nil? && @bucket < 60
  true
end