Class: Shipeasy::Admin::Generated::GetExperimentResultsResponse

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/shipeasy_admin/models/get_experiment_results_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetExperimentResultsResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/shipeasy_admin/models/get_experiment_results_response.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::GetExperimentResultsResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::GetExperimentResultsResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'experiment')
    self.experiment = attributes[:'experiment']
  else
    self.experiment = nil
  end

  if attributes.key?(:'results')
    if (value = attributes[:'results']).is_a?(Array)
      self.results = value
    end
  else
    self.results = nil
  end

  if attributes.key?(:'verdict')
    self.verdict = attributes[:'verdict']
  else
    self.verdict = nil
  end
end

Instance Attribute Details

#experimentObject

Returns the value of attribute experiment.



18
19
20
# File 'lib/shipeasy_admin/models/get_experiment_results_response.rb', line 18

def experiment
  @experiment
end

#resultsObject

Returns the value of attribute results.



20
21
22
# File 'lib/shipeasy_admin/models/get_experiment_results_response.rb', line 20

def results
  @results
end

#verdictObject

Server-computed decision from the goal metric + guardrails + SRM vs. the significance threshold and min runtime: ship (goal significant + guardrails pass), hold (a guardrail regressed), wait (inconclusive / under-powered), invalid (sample-ratio mismatch), draft (never started).



23
24
25
# File 'lib/shipeasy_admin/models/get_experiment_results_response.rb', line 23

def verdict
  @verdict
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/shipeasy_admin/models/get_experiment_results_response.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/shipeasy_admin/models/get_experiment_results_response.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
# File 'lib/shipeasy_admin/models/get_experiment_results_response.rb', line 48

def self.attribute_map
  {
    :'experiment' => :'experiment',
    :'results' => :'results',
    :'verdict' => :'verdict'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/shipeasy_admin/models/get_experiment_results_response.rb', line 205

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/shipeasy_admin/models/get_experiment_results_response.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
# File 'lib/shipeasy_admin/models/get_experiment_results_response.rb', line 67

def self.openapi_types
  {
    :'experiment' => :'GetExperimentResultsResponseExperiment',
    :'results' => :'Array<GetExperimentResultsResponseResultsInner>',
    :'verdict' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



182
183
184
185
186
187
188
# File 'lib/shipeasy_admin/models/get_experiment_results_response.rb', line 182

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      experiment == o.experiment &&
      results == o.results &&
      verdict == o.verdict
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


192
193
194
# File 'lib/shipeasy_admin/models/get_experiment_results_response.rb', line 192

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



198
199
200
# File 'lib/shipeasy_admin/models/get_experiment_results_response.rb', line 198

def hash
  [experiment, results, verdict].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/shipeasy_admin/models/get_experiment_results_response.rb', line 120

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @experiment.nil?
    invalid_properties.push('invalid value for "experiment", experiment cannot be nil.')
  end

  if @results.nil?
    invalid_properties.push('invalid value for "results", results cannot be nil.')
  end

  if @verdict.nil?
    invalid_properties.push('invalid value for "verdict", verdict cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/shipeasy_admin/models/get_experiment_results_response.rb', line 227

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



140
141
142
143
144
145
146
147
148
# File 'lib/shipeasy_admin/models/get_experiment_results_response.rb', line 140

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @experiment.nil?
  return false if @results.nil?
  return false if @verdict.nil?
  verdict_validator = EnumAttributeValidator.new('String', ["ship", "hold", "wait", "invalid", "draft"])
  return false unless verdict_validator.valid?(@verdict)
  true
end