Class: Shipeasy::Admin::Generated::GetExperimentResultsResponseResultsInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/shipeasy_admin/models/get_experiment_results_response_results_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetExperimentResultsResponseResultsInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/shipeasy_admin/models/get_experiment_results_response_results_inner.rb', line 91

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::GetExperimentResultsResponseResultsInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::GetExperimentResultsResponseResultsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'metric')
    self.metric = attributes[:'metric']
  else
    self.metric = nil
  end

  if attributes.key?(:'group_name')
    self.group_name = attributes[:'group_name']
  else
    self.group_name = nil
  end

  if attributes.key?(:'ds')
    self.ds = attributes[:'ds']
  else
    self.ds = nil
  end

  if attributes.key?(:'n')
    self.n = attributes[:'n']
  else
    self.n = nil
  end

  if attributes.key?(:'mean')
    self.mean = attributes[:'mean']
  else
    self.mean = nil
  end

  if attributes.key?(:'delta_pct')
    self.delta_pct = attributes[:'delta_pct']
  else
    self.delta_pct = nil
  end

  if attributes.key?(:'p_value')
    self.p_value = attributes[:'p_value']
  else
    self.p_value = nil
  end

  if attributes.key?(:'srm_detected')
    self.srm_detected = attributes[:'srm_detected']
  else
    self.srm_detected = nil
  end
end

Instance Attribute Details

#delta_pctObject

Returns the value of attribute delta_pct.



31
32
33
# File 'lib/shipeasy_admin/models/get_experiment_results_response_results_inner.rb', line 31

def delta_pct
  @delta_pct
end

#dsObject

Date slice (YYYY-MM-DD).



25
26
27
# File 'lib/shipeasy_admin/models/get_experiment_results_response_results_inner.rb', line 25

def ds
  @ds
end

#group_nameObject

Optional gate name. Only callers that pass the gate are enrolled in the experiment.



22
23
24
# File 'lib/shipeasy_admin/models/get_experiment_results_response_results_inner.rb', line 22

def group_name
  @group_name
end

#meanObject

Returns the value of attribute mean.



29
30
31
# File 'lib/shipeasy_admin/models/get_experiment_results_response_results_inner.rb', line 29

def mean
  @mean
end

#metricObject

Optional gate name. Only callers that pass the gate are enrolled in the experiment.



19
20
21
# File 'lib/shipeasy_admin/models/get_experiment_results_response_results_inner.rb', line 19

def metric
  @metric
end

#nObject

Returns the value of attribute n.



27
28
29
# File 'lib/shipeasy_admin/models/get_experiment_results_response_results_inner.rb', line 27

def n
  @n
end

#p_valueObject

Returns the value of attribute p_value.



33
34
35
# File 'lib/shipeasy_admin/models/get_experiment_results_response_results_inner.rb', line 33

def p_value
  @p_value
end

#srm_detectedObject

1 if sample-ratio mismatch detected, else 0.



36
37
38
# File 'lib/shipeasy_admin/models/get_experiment_results_response_results_inner.rb', line 36

def srm_detected
  @srm_detected
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/shipeasy_admin/models/get_experiment_results_response_results_inner.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/shipeasy_admin/models/get_experiment_results_response_results_inner.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
50
# File 'lib/shipeasy_admin/models/get_experiment_results_response_results_inner.rb', line 39

def self.attribute_map
  {
    :'metric' => :'metric',
    :'group_name' => :'group_name',
    :'ds' => :'ds',
    :'n' => :'n',
    :'mean' => :'mean',
    :'delta_pct' => :'delta_pct',
    :'p_value' => :'p_value',
    :'srm_detected' => :'srm_detected'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/shipeasy_admin/models/get_experiment_results_response_results_inner.rb', line 214

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



77
78
79
80
81
82
83
84
85
86
87
# File 'lib/shipeasy_admin/models/get_experiment_results_response_results_inner.rb', line 77

def self.openapi_nullable
  Set.new([
    :'metric',
    :'group_name',
    :'n',
    :'mean',
    :'delta_pct',
    :'p_value',
    :'srm_detected'
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/shipeasy_admin/models/get_experiment_results_response_results_inner.rb', line 63

def self.openapi_types
  {
    :'metric' => :'String',
    :'group_name' => :'String',
    :'ds' => :'String',
    :'n' => :'Float',
    :'mean' => :'Float',
    :'delta_pct' => :'Float',
    :'p_value' => :'Float',
    :'srm_detected' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/shipeasy_admin/models/get_experiment_results_response_results_inner.rb', line 186

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      metric == o.metric &&
      group_name == o.group_name &&
      ds == o.ds &&
      n == o.n &&
      mean == o.mean &&
      delta_pct == o.delta_pct &&
      p_value == o.p_value &&
      srm_detected == o.srm_detected
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


201
202
203
# File 'lib/shipeasy_admin/models/get_experiment_results_response_results_inner.rb', line 201

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



207
208
209
# File 'lib/shipeasy_admin/models/get_experiment_results_response_results_inner.rb', line 207

def hash
  [metric, group_name, ds, n, mean, delta_pct, p_value, srm_detected].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



156
157
158
159
160
161
162
163
164
# File 'lib/shipeasy_admin/models/get_experiment_results_response_results_inner.rb', line 156

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @ds.nil?
    invalid_properties.push('invalid value for "ds", ds cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/shipeasy_admin/models/get_experiment_results_response_results_inner.rb', line 236

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



168
169
170
171
172
# File 'lib/shipeasy_admin/models/get_experiment_results_response_results_inner.rb', line 168

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @ds.nil?
  true
end