Class: Shipeasy::Admin::Generated::LinkPrToOpsItemRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/shipeasy_admin/models/link_pr_to_ops_item_request.rb

Overview

Body for POST /api/admin/ops/{handle}/link-pr.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ LinkPrToOpsItemRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/shipeasy_admin/models/link_pr_to_ops_item_request.rb', line 60

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::LinkPrToOpsItemRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::LinkPrToOpsItemRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'pr_number')
    self.pr_number = attributes[:'pr_number']
  else
    self.pr_number = nil
  end

  if attributes.key?(:'pr_url')
    self.pr_url = attributes[:'pr_url']
  end
end

Instance Attribute Details

#pr_numberObject

PR number to record on the item. null unlinks the PR.



20
21
22
# File 'lib/shipeasy_admin/models/link_pr_to_ops_item_request.rb', line 20

def pr_number
  @pr_number
end

#pr_urlObject

Explicit PR URL. Required for error/alert tickets (no GitHub issue to derive the URL from).



23
24
25
# File 'lib/shipeasy_admin/models/link_pr_to_ops_item_request.rb', line 23

def pr_url
  @pr_url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



34
35
36
# File 'lib/shipeasy_admin/models/link_pr_to_ops_item_request.rb', line 34

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



39
40
41
# File 'lib/shipeasy_admin/models/link_pr_to_ops_item_request.rb', line 39

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



26
27
28
29
30
31
# File 'lib/shipeasy_admin/models/link_pr_to_ops_item_request.rb', line 26

def self.attribute_map
  {
    :'pr_number' => :'prNumber',
    :'pr_url' => :'prUrl'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/shipeasy_admin/models/link_pr_to_ops_item_request.rb', line 148

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



52
53
54
55
56
# File 'lib/shipeasy_admin/models/link_pr_to_ops_item_request.rb', line 52

def self.openapi_nullable
  Set.new([
    :'pr_number',
  ])
end

.openapi_typesObject

Attribute type mapping.



44
45
46
47
48
49
# File 'lib/shipeasy_admin/models/link_pr_to_ops_item_request.rb', line 44

def self.openapi_types
  {
    :'pr_number' => :'Integer',
    :'pr_url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



126
127
128
129
130
131
# File 'lib/shipeasy_admin/models/link_pr_to_ops_item_request.rb', line 126

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      pr_number == o.pr_number &&
      pr_url == o.pr_url
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


135
136
137
# File 'lib/shipeasy_admin/models/link_pr_to_ops_item_request.rb', line 135

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



141
142
143
# File 'lib/shipeasy_admin/models/link_pr_to_ops_item_request.rb', line 141

def hash
  [pr_number, pr_url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/shipeasy_admin/models/link_pr_to_ops_item_request.rb', line 87

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @pr_number > 9007199254740991
    invalid_properties.push('invalid value for "pr_number", must be smaller than or equal to 9007199254740991.')
  end

  if @pr_number <= 0
    invalid_properties.push('invalid value for "pr_number", must be greater than 0.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/shipeasy_admin/models/link_pr_to_ops_item_request.rb', line 170

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



103
104
105
106
107
108
# File 'lib/shipeasy_admin/models/link_pr_to_ops_item_request.rb', line 103

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @pr_number > 9007199254740991
  return false if @pr_number <= 0
  true
end