Class: Shipeasy::Admin::Generated::ListGatesResponseDataInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/shipeasy_admin/models/list_gates_response_data_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListGatesResponseDataInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/shipeasy_admin/models/list_gates_response_data_inner.rb', line 113

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::ListGatesResponseDataInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::ListGatesResponseDataInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  else
    self.enabled = nil
  end

  if attributes.key?(:'rollout_pct')
    self.rollout_pct = attributes[:'rollout_pct']
  else
    self.rollout_pct = nil
  end

  if attributes.key?(:'rules')
    if (value = attributes[:'rules']).is_a?(Array)
      self.rules = value
    end
  end

  if attributes.key?(:'salt')
    self.salt = attributes[:'salt']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'folder')
    self.folder = attributes[:'folder']
  end

  if attributes.key?(:'group_name')
    self.group_name = attributes[:'group_name']
  end

  if attributes.key?(:'owner_email')
    self.owner_email = attributes[:'owner_email']
  end

  if attributes.key?(:'stack')
    if (value = attributes[:'stack']).is_a?(Array)
      self.stack = value
    end
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end
end

Instance Attribute Details

#descriptionObject

Returns the value of attribute description.



36
37
38
# File 'lib/shipeasy_admin/models/list_gates_response_data_inner.rb', line 36

def description
  @description
end

#enabledObject

Returns the value of attribute enabled.



24
25
26
# File 'lib/shipeasy_admin/models/list_gates_response_data_inner.rb', line 24

def enabled
  @enabled
end

#folderObject

Returns the value of attribute folder.



38
39
40
# File 'lib/shipeasy_admin/models/list_gates_response_data_inner.rb', line 38

def folder
  @folder
end

#group_nameObject

Group label (note: groupName in response, group in request).



41
42
43
# File 'lib/shipeasy_admin/models/list_gates_response_data_inner.rb', line 41

def group_name
  @group_name
end

#idObject

Stable opaque gate id (gat_…).



19
20
21
# File 'lib/shipeasy_admin/models/list_gates_response_data_inner.rb', line 19

def id
  @id
end

#nameObject

Stable gate key used by SDKs (Shipeasy.checkGate(user, '<name>')). Single segment or folder.name. Lowercase letters, digits, _ or -; max 128 chars. Immutable after create — rename = delete + recreate.



22
23
24
# File 'lib/shipeasy_admin/models/list_gates_response_data_inner.rb', line 22

def name
  @name
end

#owner_emailObject

Owner email (note: ownerEmail in response, owner_email in request).



44
45
46
# File 'lib/shipeasy_admin/models/list_gates_response_data_inner.rb', line 44

def owner_email
  @owner_email
end

#rollout_pctObject

Current rollout in basis points (0–10000).



27
28
29
# File 'lib/shipeasy_admin/models/list_gates_response_data_inner.rb', line 27

def rollout_pct
  @rollout_pct
end

#rulesObject

Returns the value of attribute rules.



29
30
31
# File 'lib/shipeasy_admin/models/list_gates_response_data_inner.rb', line 29

def rules
  @rules
end

#saltObject

Hash salt used for percentage bucketing.



32
33
34
# File 'lib/shipeasy_admin/models/list_gates_response_data_inner.rb', line 32

def salt
  @salt
end

#stackObject

Returns the value of attribute stack.



46
47
48
# File 'lib/shipeasy_admin/models/list_gates_response_data_inner.rb', line 46

def stack
  @stack
end

#titleObject

Returns the value of attribute title.



34
35
36
# File 'lib/shipeasy_admin/models/list_gates_response_data_inner.rb', line 34

def title
  @title
end

#updated_atObject

ISO-8601 timestamp of last mutation.



49
50
51
# File 'lib/shipeasy_admin/models/list_gates_response_data_inner.rb', line 49

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/shipeasy_admin/models/list_gates_response_data_inner.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/shipeasy_admin/models/list_gates_response_data_inner.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/shipeasy_admin/models/list_gates_response_data_inner.rb', line 52

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'enabled' => :'enabled',
    :'rollout_pct' => :'rolloutPct',
    :'rules' => :'rules',
    :'salt' => :'salt',
    :'title' => :'title',
    :'description' => :'description',
    :'folder' => :'folder',
    :'group_name' => :'groupName',
    :'owner_email' => :'ownerEmail',
    :'stack' => :'stack',
    :'updated_at' => :'updatedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
# File 'lib/shipeasy_admin/models/list_gates_response_data_inner.rb', line 357

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



100
101
102
103
104
105
106
107
108
109
# File 'lib/shipeasy_admin/models/list_gates_response_data_inner.rb', line 100

def self.openapi_nullable
  Set.new([
    :'title',
    :'description',
    :'folder',
    :'group_name',
    :'owner_email',
    :'stack',
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/shipeasy_admin/models/list_gates_response_data_inner.rb', line 81

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'enabled' => :'ListGatesResponseDataInnerEnabled',
    :'rollout_pct' => :'Integer',
    :'rules' => :'Array<ListGatesResponseDataInnerRulesInner>',
    :'salt' => :'String',
    :'title' => :'String',
    :'description' => :'String',
    :'folder' => :'String',
    :'group_name' => :'String',
    :'owner_email' => :'String',
    :'stack' => :'Array<ListGatesResponseDataInnerStackInner>',
    :'updated_at' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
# File 'lib/shipeasy_admin/models/list_gates_response_data_inner.rb', line 324

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      enabled == o.enabled &&
      rollout_pct == o.rollout_pct &&
      rules == o.rules &&
      salt == o.salt &&
      title == o.title &&
      description == o.description &&
      folder == o.folder &&
      group_name == o.group_name &&
      owner_email == o.owner_email &&
      stack == o.stack &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


344
345
346
# File 'lib/shipeasy_admin/models/list_gates_response_data_inner.rb', line 344

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



350
351
352
# File 'lib/shipeasy_admin/models/list_gates_response_data_inner.rb', line 350

def hash
  [id, name, enabled, rollout_pct, rules, salt, title, description, folder, group_name, owner_email, stack, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/shipeasy_admin/models/list_gates_response_data_inner.rb', line 196

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 128
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 128.')
  end

  pattern = Regexp.new(/^[a-z0-9](?:[a-z0-9_-]*[a-z0-9])?(?:\.[a-z0-9](?:[a-z0-9_-]*[a-z0-9])?)?$/)
  if @name !~ pattern
    invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.")
  end

  if @enabled.nil?
    invalid_properties.push('invalid value for "enabled", enabled cannot be nil.')
  end

  if @rollout_pct.nil?
    invalid_properties.push('invalid value for "rollout_pct", rollout_pct cannot be nil.')
  end

  if @rollout_pct > 10000
    invalid_properties.push('invalid value for "rollout_pct", must be smaller than or equal to 10000.')
  end

  if @rollout_pct < 0
    invalid_properties.push('invalid value for "rollout_pct", must be greater than or equal to 0.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/shipeasy_admin/models/list_gates_response_data_inner.rb', line 379

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/shipeasy_admin/models/list_gates_response_data_inner.rb', line 241

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @name.to_s.length > 128
  return false if @name !~ Regexp.new(/^[a-z0-9](?:[a-z0-9_-]*[a-z0-9])?(?:\.[a-z0-9](?:[a-z0-9_-]*[a-z0-9])?)?$/)
  return false if @enabled.nil?
  return false if @rollout_pct.nil?
  return false if @rollout_pct > 10000
  return false if @rollout_pct < 0
  return false if @updated_at.nil?
  true
end