Class: Shipeasy::Admin::Generated::ListI18nKeysResponseKeysInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/shipeasy_admin/models/list_i18n_keys_response_keys_inner.rb

Overview

One i18n key row.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListI18nKeysResponseKeysInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/shipeasy_admin/models/list_i18n_keys_response_keys_inner.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::ListI18nKeysResponseKeysInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::ListI18nKeysResponseKeysInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  else
    self.value = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'variables')
    if (value = attributes[:'variables']).is_a?(Array)
      self.variables = value
    end
  end

  if attributes.key?(:'profile_id')
    self.profile_id = attributes[:'profile_id']
  end

  if attributes.key?(:'chunk_id')
    self.chunk_id = attributes[:'chunk_id']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'updated_by')
    self.updated_by = attributes[:'updated_by']
  end
end

Instance Attribute Details

#chunk_idObject

Owning chunk (authoring grouping) id.



38
39
40
# File 'lib/shipeasy_admin/models/list_i18n_keys_response_keys_inner.rb', line 38

def chunk_id
  @chunk_id
end

#descriptionObject

Optional human note stored with the key.



29
30
31
# File 'lib/shipeasy_admin/models/list_i18n_keys_response_keys_inner.rb', line 29

def description
  @description
end

#idObject

Stable opaque key id.



20
21
22
# File 'lib/shipeasy_admin/models/list_i18n_keys_response_keys_inner.rb', line 20

def id
  @id
end

#keyObject

Dotted key path, e.g. home.cta.



23
24
25
# File 'lib/shipeasy_admin/models/list_i18n_keys_response_keys_inner.rb', line 23

def key
  @key
end

#profile_idObject

Owning profile id.



35
36
37
# File 'lib/shipeasy_admin/models/list_i18n_keys_response_keys_inner.rb', line 35

def profile_id
  @profile_id
end

#updated_atObject

ISO-8601 timestamp of the last edit.



41
42
43
# File 'lib/shipeasy_admin/models/list_i18n_keys_response_keys_inner.rb', line 41

def updated_at
  @updated_at
end

#updated_byObject

Actor email that last edited the key.



44
45
46
# File 'lib/shipeasy_admin/models/list_i18n_keys_response_keys_inner.rb', line 44

def updated_by
  @updated_by
end

#valueObject

Current translated value for the key.



26
27
28
# File 'lib/shipeasy_admin/models/list_i18n_keys_response_keys_inner.rb', line 26

def value
  @value
end

#variablesObject

{{var}} placeholder names in the value, or null when there are none.



32
33
34
# File 'lib/shipeasy_admin/models/list_i18n_keys_response_keys_inner.rb', line 32

def variables
  @variables
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



62
63
64
# File 'lib/shipeasy_admin/models/list_i18n_keys_response_keys_inner.rb', line 62

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



67
68
69
# File 'lib/shipeasy_admin/models/list_i18n_keys_response_keys_inner.rb', line 67

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/shipeasy_admin/models/list_i18n_keys_response_keys_inner.rb', line 47

def self.attribute_map
  {
    :'id' => :'id',
    :'key' => :'key',
    :'value' => :'value',
    :'description' => :'description',
    :'variables' => :'variables',
    :'profile_id' => :'profileId',
    :'chunk_id' => :'chunkId',
    :'updated_at' => :'updatedAt',
    :'updated_by' => :'updatedBy'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/shipeasy_admin/models/list_i18n_keys_response_keys_inner.rb', line 246

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



87
88
89
90
91
92
# File 'lib/shipeasy_admin/models/list_i18n_keys_response_keys_inner.rb', line 87

def self.openapi_nullable
  Set.new([
    :'description',
    :'variables',
  ])
end

.openapi_typesObject

Attribute type mapping.



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/shipeasy_admin/models/list_i18n_keys_response_keys_inner.rb', line 72

def self.openapi_types
  {
    :'id' => :'String',
    :'key' => :'String',
    :'value' => :'String',
    :'description' => :'String',
    :'variables' => :'Array<String>',
    :'profile_id' => :'String',
    :'chunk_id' => :'String',
    :'updated_at' => :'String',
    :'updated_by' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/shipeasy_admin/models/list_i18n_keys_response_keys_inner.rb', line 217

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      key == o.key &&
      value == o.value &&
      description == o.description &&
      variables == o.variables &&
      profile_id == o.profile_id &&
      chunk_id == o.chunk_id &&
      updated_at == o.updated_at &&
      updated_by == o.updated_by
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


233
234
235
# File 'lib/shipeasy_admin/models/list_i18n_keys_response_keys_inner.rb', line 233

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



239
240
241
# File 'lib/shipeasy_admin/models/list_i18n_keys_response_keys_inner.rb', line 239

def hash
  [id, key, value, description, variables, profile_id, chunk_id, updated_at, updated_by].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/shipeasy_admin/models/list_i18n_keys_response_keys_inner.rb', line 157

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @value.nil?
    invalid_properties.push('invalid value for "value", value cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/shipeasy_admin/models/list_i18n_keys_response_keys_inner.rb', line 268

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



177
178
179
180
181
182
183
# File 'lib/shipeasy_admin/models/list_i18n_keys_response_keys_inner.rb', line 177

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @key.nil?
  return false if @value.nil?
  true
end