Class: Shipeasy::Admin::Generated::ListMetricsResponseInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Shipeasy::Admin::Generated::ListMetricsResponseInner
- Defined in:
- lib/shipeasy_admin/models/list_metrics_response_inner.rb
Overview
A metric definition.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#aggregation ⇒ Object
Legacy aggregation enum derived from the IR (
count_users,sum,ratio, …). -
#created_at ⇒ Object
ISO-8601 creation timestamp.
-
#direction ⇒ Object
Desired direction of movement.
-
#event_name ⇒ Object
Source event name (camelCase in response).
-
#folder ⇒ Object
Folder grouping the metric, or
null. -
#id ⇒ Object
Stable opaque metric id.
-
#min_detectable_effect ⇒ Object
Configured MDE, or
null. -
#name ⇒ Object
Metric key.
-
#query ⇒ Object
Rendered DSL text form of the query, or
nullif it could not be rendered. -
#query_ir ⇒ Object
Returns the value of attribute query_ir.
-
#updated_at ⇒ Object
ISO-8601 last-update timestamp.
-
#value_path ⇒ Object
Numeric value label for sum/avg metrics, or
null. -
#winsorize_pct ⇒ Object
Winsorise percentile applied to the metric.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListMetricsResponseInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListMetricsResponseInner
Initializes the object
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner.rb', line 139 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::ListMetricsResponseInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::ListMetricsResponseInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'folder') self.folder = attributes[:'folder'] else self.folder = nil end if attributes.key?(:'event_name') self.event_name = attributes[:'event_name'] else self.event_name = nil end if attributes.key?(:'aggregation') self.aggregation = attributes[:'aggregation'] else self.aggregation = nil end if attributes.key?(:'value_path') self.value_path = attributes[:'value_path'] else self.value_path = nil end if attributes.key?(:'query') self.query = attributes[:'query'] end if attributes.key?(:'query_ir') self.query_ir = attributes[:'query_ir'] end if attributes.key?(:'direction') self.direction = attributes[:'direction'] end if attributes.key?(:'winsorize_pct') self.winsorize_pct = attributes[:'winsorize_pct'] end if attributes.key?(:'min_detectable_effect') self.min_detectable_effect = attributes[:'min_detectable_effect'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#aggregation ⇒ Object
Legacy aggregation enum derived from the IR (count_users, sum, ratio, …).
32 33 34 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner.rb', line 32 def aggregation @aggregation end |
#created_at ⇒ Object
ISO-8601 creation timestamp.
52 53 54 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner.rb', line 52 def created_at @created_at end |
#direction ⇒ Object
Desired direction of movement. higher_better (default), lower_better, or neutral (guardrail).
43 44 45 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner.rb', line 43 def direction @direction end |
#event_name ⇒ Object
Source event name (camelCase in response).
29 30 31 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner.rb', line 29 def event_name @event_name end |
#folder ⇒ Object
Folder grouping the metric, or null.
26 27 28 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner.rb', line 26 def folder @folder end |
#id ⇒ Object
Stable opaque metric id.
20 21 22 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner.rb', line 20 def id @id end |
#min_detectable_effect ⇒ Object
Configured MDE, or null.
49 50 51 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner.rb', line 49 def min_detectable_effect @min_detectable_effect end |
#name ⇒ Object
Metric key.
23 24 25 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner.rb', line 23 def name @name end |
#query ⇒ Object
Rendered DSL text form of the query, or null if it could not be rendered.
38 39 40 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner.rb', line 38 def query @query end |
#query_ir ⇒ Object
Returns the value of attribute query_ir.
40 41 42 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner.rb', line 40 def query_ir @query_ir end |
#updated_at ⇒ Object
ISO-8601 last-update timestamp.
55 56 57 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner.rb', line 55 def updated_at @updated_at end |
#value_path ⇒ Object
Numeric value label for sum/avg metrics, or null.
35 36 37 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner.rb', line 35 def value_path @value_path end |
#winsorize_pct ⇒ Object
Winsorise percentile applied to the metric.
46 47 48 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner.rb', line 46 def winsorize_pct @winsorize_pct end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
99 100 101 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner.rb', line 99 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
104 105 106 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner.rb', line 104 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner.rb', line 80 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'folder' => :'folder', :'event_name' => :'eventName', :'aggregation' => :'aggregation', :'value_path' => :'valuePath', :'query' => :'query', :'query_ir' => :'queryIr', :'direction' => :'direction', :'winsorize_pct' => :'winsorizePct', :'min_detectable_effect' => :'minDetectableEffect', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner.rb', line 340 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
128 129 130 131 132 133 134 135 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner.rb', line 128 def self.openapi_nullable Set.new([ :'folder', :'value_path', :'query', :'min_detectable_effect', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner.rb', line 109 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'folder' => :'String', :'event_name' => :'String', :'aggregation' => :'String', :'value_path' => :'String', :'query' => :'String', :'query_ir' => :'ListMetricsResponseInnerQueryIr', :'direction' => :'String', :'winsorize_pct' => :'Float', :'min_detectable_effect' => :'Float', :'created_at' => :'String', :'updated_at' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner.rb', line 307 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && folder == o.folder && event_name == o.event_name && aggregation == o.aggregation && value_path == o.value_path && query == o.query && query_ir == o.query_ir && direction == o.direction && winsorize_pct == o.winsorize_pct && min_detectable_effect == o.min_detectable_effect && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
327 328 329 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner.rb', line 327 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
333 334 335 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner.rb', line 333 def hash [id, name, folder, event_name, aggregation, value_path, query, query_ir, direction, winsorize_pct, min_detectable_effect, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner.rb', line 220 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @event_name.nil? invalid_properties.push('invalid value for "event_name", event_name cannot be nil.') end if @aggregation.nil? invalid_properties.push('invalid value for "aggregation", aggregation cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
362 363 364 365 366 367 368 369 370 371 372 373 374 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner.rb', line 362 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
244 245 246 247 248 249 250 251 252 253 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner.rb', line 244 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @name.nil? return false if @event_name.nil? return false if @aggregation.nil? direction_validator = EnumAttributeValidator.new('String', ["higher_better", "lower_better", "neutral"]) return false unless direction_validator.valid?(@direction) true end |