Class: Shipeasy::Admin::Generated::ListMetricsResponseInnerQueryIrAggOneOf9Numerator

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/shipeasy_admin/models/list_metrics_response_inner_query_ir_agg_one_of9_numerator.rb

Overview

Numerator or denominator arm of a ratio aggregation.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListMetricsResponseInnerQueryIrAggOneOf9Numerator

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir_agg_one_of9_numerator.rb', line 86

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::ListMetricsResponseInnerQueryIrAggOneOf9Numerator` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::ListMetricsResponseInnerQueryIrAggOneOf9Numerator`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'agg')
    self.agg = attributes[:'agg']
  else
    self.agg = nil
  end

  if attributes.key?(:'metric')
    self.metric = attributes[:'metric']
  else
    self.metric = nil
  end

  if attributes.key?(:'filters')
    if (value = attributes[:'filters']).is_a?(Array)
      self.filters = value
    end
  end
end

Instance Attribute Details

#aggObject

Counting mode for this ratio arm.



20
21
22
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir_agg_one_of9_numerator.rb', line 20

def agg
  @agg
end

#filtersObject

Optional label filters.



26
27
28
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir_agg_one_of9_numerator.rb', line 26

def filters
  @filters
end

#metricObject

Source event name for this ratio arm.



23
24
25
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir_agg_one_of9_numerator.rb', line 23

def metric
  @metric
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



60
61
62
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir_agg_one_of9_numerator.rb', line 60

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



65
66
67
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir_agg_one_of9_numerator.rb', line 65

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir_agg_one_of9_numerator.rb', line 51

def self.attribute_map
  {
    :'agg' => :'agg',
    :'metric' => :'metric',
    :'filters' => :'filters'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir_agg_one_of9_numerator.rb', line 228

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



79
80
81
82
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir_agg_one_of9_numerator.rb', line 79

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir_agg_one_of9_numerator.rb', line 70

def self.openapi_types
  {
    :'agg' => :'String',
    :'metric' => :'String',
    :'filters' => :'Array<ListMetricsResponseInnerQueryIrAggOneOf9NumeratorFiltersInner>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



205
206
207
208
209
210
211
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir_agg_one_of9_numerator.rb', line 205

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      agg == o.agg &&
      metric == o.metric &&
      filters == o.filters
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


215
216
217
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir_agg_one_of9_numerator.rb', line 215

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



221
222
223
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir_agg_one_of9_numerator.rb', line 221

def hash
  [agg, metric, filters].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir_agg_one_of9_numerator.rb', line 121

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @agg.nil?
    invalid_properties.push('invalid value for "agg", agg cannot be nil.')
  end

  if @metric.nil?
    invalid_properties.push('invalid value for "metric", metric cannot be nil.')
  end

  if @metric.to_s.length > 128
    invalid_properties.push('invalid value for "metric", the character length must be smaller than or equal to 128.')
  end

  if @metric.to_s.length < 1
    invalid_properties.push('invalid value for "metric", the character length must be greater than or equal to 1.')
  end

  if !@filters.nil? && @filters.length > 16
    invalid_properties.push('invalid value for "filters", number of items must be less than or equal to 16.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir_agg_one_of9_numerator.rb', line 250

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



149
150
151
152
153
154
155
156
157
158
159
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir_agg_one_of9_numerator.rb', line 149

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @agg.nil?
  agg_validator = EnumAttributeValidator.new('String', ["count_users", "count_events"])
  return false unless agg_validator.valid?(@agg)
  return false if @metric.nil?
  return false if @metric.to_s.length > 128
  return false if @metric.to_s.length < 1
  return false if !@filters.nil? && @filters.length > 16
  true
end