Class: Shipeasy::Admin::Generated::ListOpsItemsResponseInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/shipeasy_admin/models/list_ops_items_response_inner.rb

Overview

One queue item — any type.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListOpsItemsResponseInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/shipeasy_admin/models/list_ops_items_response_inner.rb', line 114

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::ListOpsItemsResponseInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::ListOpsItemsResponseInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'number')
    self.number = attributes[:'number']
  else
    self.number = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'priority')
    self.priority = attributes[:'priority']
  else
    self.priority = nil
  end

  if attributes.key?(:'source_ref')
    self.source_ref = attributes[:'source_ref']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end
end

Instance Attribute Details

#created_atObject

ISO-8601 creation timestamp.



41
42
43
# File 'lib/shipeasy_admin/models/list_ops_items_response_inner.rb', line 41

def created_at
  @created_at
end

#idObject

Stable opaque item id.



20
21
22
# File 'lib/shipeasy_admin/models/list_ops_items_response_inner.rb', line 20

def id
  @id
end

#numberObject

Per-project item number (the #7 handle), or null if unnumbered.



23
24
25
# File 'lib/shipeasy_admin/models/list_ops_items_response_inner.rb', line 23

def number
  @number
end

#priorityObject

Triage priority of a queue item.



35
36
37
# File 'lib/shipeasy_admin/models/list_ops_items_response_inner.rb', line 35

def priority
  @priority
end

#source_refObject

Source reference for auto-filed tickets (e.g. an error fingerprint).



38
39
40
# File 'lib/shipeasy_admin/models/list_ops_items_response_inner.rb', line 38

def source_ref
  @source_ref
end

#statusObject

Lifecycle status of a queue item.



32
33
34
# File 'lib/shipeasy_admin/models/list_ops_items_response_inner.rb', line 32

def status
  @status
end

#titleObject

One-line item title.



29
30
31
# File 'lib/shipeasy_admin/models/list_ops_items_response_inner.rb', line 29

def title
  @title
end

#typeObject

Queue item type. bug and feature_request are user-fileable; error and alert tickets are auto-filed by the platform.



26
27
28
# File 'lib/shipeasy_admin/models/list_ops_items_response_inner.rb', line 26

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



80
81
82
# File 'lib/shipeasy_admin/models/list_ops_items_response_inner.rb', line 80

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



85
86
87
# File 'lib/shipeasy_admin/models/list_ops_items_response_inner.rb', line 85

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/shipeasy_admin/models/list_ops_items_response_inner.rb', line 66

def self.attribute_map
  {
    :'id' => :'id',
    :'number' => :'number',
    :'type' => :'type',
    :'title' => :'title',
    :'status' => :'status',
    :'priority' => :'priority',
    :'source_ref' => :'sourceRef',
    :'created_at' => :'createdAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/shipeasy_admin/models/list_ops_items_response_inner.rb', line 311

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



104
105
106
107
108
109
110
# File 'lib/shipeasy_admin/models/list_ops_items_response_inner.rb', line 104

def self.openapi_nullable
  Set.new([
    :'number',
    :'priority',
    :'source_ref',
  ])
end

.openapi_typesObject

Attribute type mapping.



90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/shipeasy_admin/models/list_ops_items_response_inner.rb', line 90

def self.openapi_types
  {
    :'id' => :'String',
    :'number' => :'Float',
    :'type' => :'String',
    :'title' => :'String',
    :'status' => :'String',
    :'priority' => :'String',
    :'source_ref' => :'String',
    :'created_at' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/shipeasy_admin/models/list_ops_items_response_inner.rb', line 283

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      number == o.number &&
      type == o.type &&
      title == o.title &&
      status == o.status &&
      priority == o.priority &&
      source_ref == o.source_ref &&
      created_at == o.created_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


298
299
300
# File 'lib/shipeasy_admin/models/list_ops_items_response_inner.rb', line 298

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



304
305
306
# File 'lib/shipeasy_admin/models/list_ops_items_response_inner.rb', line 304

def hash
  [id, number, type, title, status, priority, source_ref, created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/shipeasy_admin/models/list_ops_items_response_inner.rb', line 177

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/shipeasy_admin/models/list_ops_items_response_inner.rb', line 333

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/shipeasy_admin/models/list_ops_items_response_inner.rb', line 205

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["bug", "feature_request", "error", "alert"])
  return false unless type_validator.valid?(@type)
  return false if @title.nil?
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["open", "triaged", "in_progress", "ready_for_qa", "resolved", "wont_fix"])
  return false unless status_validator.valid?(@status)
  priority_validator = EnumAttributeValidator.new('String', ["nice_to_have", "medium", "high", "critical"])
  return false unless priority_validator.valid?(@priority)
  return false if @created_at.nil?
  true
end