Class: Shipeasy::Admin::Generated::ListUniversesResponseDataInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Shipeasy::Admin::Generated::ListUniversesResponseDataInner
- Defined in:
- lib/shipeasy_admin/models/list_universes_response_data_inner.rb
Instance Attribute Summary collapse
-
#created_at ⇒ Object
ISO-8601 timestamp of creation.
-
#holdout_range ⇒ Object
Reserved holdout bucket range, or
nullif none. -
#id ⇒ Object
Stable opaque universe id.
-
#name ⇒ Object
Stable universe key.
-
#unit_type ⇒ Object
Unit of randomisation.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListUniversesResponseDataInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListUniversesResponseDataInner
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/shipeasy_admin/models/list_universes_response_data_inner.rb', line 74 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::ListUniversesResponseDataInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::ListUniversesResponseDataInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'unit_type') self.unit_type = attributes[:'unit_type'] else self.unit_type = nil end if attributes.key?(:'holdout_range') if (value = attributes[:'holdout_range']).is_a?(Array) self.holdout_range = value end else self.holdout_range = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end end |
Instance Attribute Details
#created_at ⇒ Object
ISO-8601 timestamp of creation.
31 32 33 |
# File 'lib/shipeasy_admin/models/list_universes_response_data_inner.rb', line 31 def created_at @created_at end |
#holdout_range ⇒ Object
Reserved holdout bucket range, or null if none.
28 29 30 |
# File 'lib/shipeasy_admin/models/list_universes_response_data_inner.rb', line 28 def holdout_range @holdout_range end |
#id ⇒ Object
Stable opaque universe id.
19 20 21 |
# File 'lib/shipeasy_admin/models/list_universes_response_data_inner.rb', line 19 def id @id end |
#name ⇒ Object
Stable universe key. Single segment or folder.name. Lowercase letters, digits, _ or -; max 128 chars. Immutable after create.
22 23 24 |
# File 'lib/shipeasy_admin/models/list_universes_response_data_inner.rb', line 22 def name @name end |
#unit_type ⇒ Object
Unit of randomisation. Snake-case in request (unit_type), camelCase in response.
25 26 27 |
# File 'lib/shipeasy_admin/models/list_universes_response_data_inner.rb', line 25 def unit_type @unit_type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/shipeasy_admin/models/list_universes_response_data_inner.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/shipeasy_admin/models/list_universes_response_data_inner.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 |
# File 'lib/shipeasy_admin/models/list_universes_response_data_inner.rb', line 34 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'unit_type' => :'unitType', :'holdout_range' => :'holdoutRange', :'created_at' => :'createdAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/shipeasy_admin/models/list_universes_response_data_inner.rb', line 267 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 70 |
# File 'lib/shipeasy_admin/models/list_universes_response_data_inner.rb', line 66 def self.openapi_nullable Set.new([ :'holdout_range', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 |
# File 'lib/shipeasy_admin/models/list_universes_response_data_inner.rb', line 55 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'unit_type' => :'String', :'holdout_range' => :'Array<Float>', :'created_at' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
242 243 244 245 246 247 248 249 250 |
# File 'lib/shipeasy_admin/models/list_universes_response_data_inner.rb', line 242 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && unit_type == o.unit_type && holdout_range == o.holdout_range && created_at == o.created_at end |
#eql?(o) ⇒ Boolean
254 255 256 |
# File 'lib/shipeasy_admin/models/list_universes_response_data_inner.rb', line 254 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
260 261 262 |
# File 'lib/shipeasy_admin/models/list_universes_response_data_inner.rb', line 260 def hash [id, name, unit_type, holdout_range, created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/shipeasy_admin/models/list_universes_response_data_inner.rb', line 123 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 128 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 128.') end pattern = Regexp.new(/^[a-z0-9](?:[a-z0-9_-]*[a-z0-9])?(?:\.[a-z0-9](?:[a-z0-9_-]*[a-z0-9])?)?$/) if @name !~ pattern invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.") end if @unit_type.nil? invalid_properties.push('invalid value for "unit_type", unit_type cannot be nil.') end if @holdout_range.length > 2 invalid_properties.push('invalid value for "holdout_range", number of items must be less than or equal to 2.') end if @holdout_range.length < 2 invalid_properties.push('invalid value for "holdout_range", number of items must be greater than or equal to 2.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/shipeasy_admin/models/list_universes_response_data_inner.rb', line 289 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/shipeasy_admin/models/list_universes_response_data_inner.rb', line 164 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @name.nil? return false if @name.to_s.length > 128 return false if @name !~ Regexp.new(/^[a-z0-9](?:[a-z0-9_-]*[a-z0-9])?(?:\.[a-z0-9](?:[a-z0-9_-]*[a-z0-9])?)?$/) return false if @unit_type.nil? return false if @holdout_range.length > 2 return false if @holdout_range.length < 2 return false if @created_at.nil? true end |