Class: Shipeasy::Admin::Generated::SaveConfigDraftRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Shipeasy::Admin::Generated::SaveConfigDraftRequest
- Defined in:
- lib/shipeasy_admin/models/save_config_draft_request.rb
Overview
Body for PUT /api/admin/configs/{id}/drafts. Stages a value for a single env without publishing.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#env ⇒ Object
Target environment.
-
#value ⇒ Object
Returns the value of attribute value.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SaveConfigDraftRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SaveConfigDraftRequest
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/shipeasy_admin/models/save_config_draft_request.rb', line 81 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::SaveConfigDraftRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::SaveConfigDraftRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'env') self.env = attributes[:'env'] else self.env = nil end if attributes.key?(:'value') self.value = attributes[:'value'] else self.value = nil end end |
Instance Attribute Details
#env ⇒ Object
Target environment. One of the project's configured envs (dev, stage, prod).
20 21 22 |
# File 'lib/shipeasy_admin/models/save_config_draft_request.rb', line 20 def env @env end |
#value ⇒ Object
Returns the value of attribute value.
22 23 24 |
# File 'lib/shipeasy_admin/models/save_config_draft_request.rb', line 22 def value @value end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
55 56 57 |
# File 'lib/shipeasy_admin/models/save_config_draft_request.rb', line 55 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
60 61 62 |
# File 'lib/shipeasy_admin/models/save_config_draft_request.rb', line 60 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 |
# File 'lib/shipeasy_admin/models/save_config_draft_request.rb', line 47 def self.attribute_map { :'env' => :'env', :'value' => :'value' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/shipeasy_admin/models/save_config_draft_request.rb', line 164 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
73 74 75 76 77 |
# File 'lib/shipeasy_admin/models/save_config_draft_request.rb', line 73 def self.openapi_nullable Set.new([ :'value' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 |
# File 'lib/shipeasy_admin/models/save_config_draft_request.rb', line 65 def self.openapi_types { :'env' => :'String', :'value' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
142 143 144 145 146 147 |
# File 'lib/shipeasy_admin/models/save_config_draft_request.rb', line 142 def ==(o) return true if self.equal?(o) self.class == o.class && env == o.env && value == o.value end |
#eql?(o) ⇒ Boolean
151 152 153 |
# File 'lib/shipeasy_admin/models/save_config_draft_request.rb', line 151 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
157 158 159 |
# File 'lib/shipeasy_admin/models/save_config_draft_request.rb', line 157 def hash [env, value].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
110 111 112 113 114 115 116 117 118 |
# File 'lib/shipeasy_admin/models/save_config_draft_request.rb', line 110 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @env.nil? invalid_properties.push('invalid value for "env", env cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/shipeasy_admin/models/save_config_draft_request.rb', line 186 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
122 123 124 125 126 127 128 |
# File 'lib/shipeasy_admin/models/save_config_draft_request.rb', line 122 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @env.nil? env_validator = EnumAttributeValidator.new('String', ["dev", "staging", "prod"]) return false unless env_validator.valid?(@env) true end |