Class: Shipeasy::Admin::Generated::SetKillswitchSwitchRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/shipeasy_admin/models/set_killswitch_switch_request.rb

Overview

Body for PUT /api/admin/killswitches/{id}/switch. Sets or updates one switch entry on one env.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SetKillswitchSwitchRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/shipeasy_admin/models/set_killswitch_switch_request.rb', line 86

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::SetKillswitchSwitchRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::SetKillswitchSwitchRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'env')
    self.env = attributes[:'env']
  else
    self.env = nil
  end

  if attributes.key?(:'switch_key')
    self.switch_key = attributes[:'switch_key']
  else
    self.switch_key = nil
  end

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  else
    self.value = nil
  end
end

Instance Attribute Details

#envObject

Target environment (dev/stage/prod).



20
21
22
# File 'lib/shipeasy_admin/models/set_killswitch_switch_request.rb', line 20

def env
  @env
end

#switch_keyObject

Switch key to set.



23
24
25
# File 'lib/shipeasy_admin/models/set_killswitch_switch_request.rb', line 23

def switch_key
  @switch_key
end

#valueObject

New boolean value for this switchKey on this env.



26
27
28
# File 'lib/shipeasy_admin/models/set_killswitch_switch_request.rb', line 26

def value
  @value
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



60
61
62
# File 'lib/shipeasy_admin/models/set_killswitch_switch_request.rb', line 60

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



65
66
67
# File 'lib/shipeasy_admin/models/set_killswitch_switch_request.rb', line 65

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
# File 'lib/shipeasy_admin/models/set_killswitch_switch_request.rb', line 51

def self.attribute_map
  {
    :'env' => :'env',
    :'switch_key' => :'switchKey',
    :'value' => :'value'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/shipeasy_admin/models/set_killswitch_switch_request.rb', line 226

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



79
80
81
82
# File 'lib/shipeasy_admin/models/set_killswitch_switch_request.rb', line 79

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
# File 'lib/shipeasy_admin/models/set_killswitch_switch_request.rb', line 70

def self.openapi_types
  {
    :'env' => :'String',
    :'switch_key' => :'String',
    :'value' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



203
204
205
206
207
208
209
# File 'lib/shipeasy_admin/models/set_killswitch_switch_request.rb', line 203

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      env == o.env &&
      switch_key == o.switch_key &&
      value == o.value
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


213
214
215
# File 'lib/shipeasy_admin/models/set_killswitch_switch_request.rb', line 213

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



219
220
221
# File 'lib/shipeasy_admin/models/set_killswitch_switch_request.rb', line 219

def hash
  [env, switch_key, value].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/shipeasy_admin/models/set_killswitch_switch_request.rb', line 121

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @env.nil?
    invalid_properties.push('invalid value for "env", env cannot be nil.')
  end

  if @switch_key.nil?
    invalid_properties.push('invalid value for "switch_key", switch_key cannot be nil.')
  end

  if @switch_key.to_s.length > 64
    invalid_properties.push('invalid value for "switch_key", the character length must be smaller than or equal to 64.')
  end

  pattern = Regexp.new(/^[a-z0-9](?:[a-z0-9_-]*[a-z0-9])?$/)
  if @switch_key !~ pattern
    invalid_properties.push("invalid value for \"switch_key\", must conform to the pattern #{pattern}.")
  end

  if @value.nil?
    invalid_properties.push('invalid value for "value", value cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/shipeasy_admin/models/set_killswitch_switch_request.rb', line 248

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



150
151
152
153
154
155
156
157
158
159
160
# File 'lib/shipeasy_admin/models/set_killswitch_switch_request.rb', line 150

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @env.nil?
  env_validator = EnumAttributeValidator.new('String', ["dev", "staging", "prod"])
  return false unless env_validator.valid?(@env)
  return false if @switch_key.nil?
  return false if @switch_key.to_s.length > 64
  return false if @switch_key !~ Regexp.new(/^[a-z0-9](?:[a-z0-9_-]*[a-z0-9])?$/)
  return false if @value.nil?
  true
end