Class: Shipeasy::Admin::Generated::UnsetKillswitchSwitchResponse

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/shipeasy_admin/models/unset_killswitch_switch_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UnsetKillswitchSwitchResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/shipeasy_admin/models/unset_killswitch_switch_response.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::UnsetKillswitchSwitchResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::UnsetKillswitchSwitchResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'env')
    self.env = attributes[:'env']
  else
    self.env = nil
  end

  if attributes.key?(:'switch_key')
    self.switch_key = attributes[:'switch_key']
  else
    self.switch_key = nil
  end

  if attributes.key?(:'removed')
    self.removed = attributes[:'removed']
  else
    self.removed = nil
  end
end

Instance Attribute Details

#envObject

Returns the value of attribute env.



20
21
22
# File 'lib/shipeasy_admin/models/unset_killswitch_switch_response.rb', line 20

def env
  @env
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/shipeasy_admin/models/unset_killswitch_switch_response.rb', line 18

def id
  @id
end

#removedObject

true if the entry existed and was removed, false if no-op.



26
27
28
# File 'lib/shipeasy_admin/models/unset_killswitch_switch_response.rb', line 26

def removed
  @removed
end

#switch_keyObject

Single-segment switch key (lowercase letters, digits, _/-; no dots). Used as the nested switch entry inside a killswitch's switches map.



23
24
25
# File 'lib/shipeasy_admin/models/unset_killswitch_switch_response.rb', line 23

def switch_key
  @switch_key
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



61
62
63
# File 'lib/shipeasy_admin/models/unset_killswitch_switch_response.rb', line 61

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



66
67
68
# File 'lib/shipeasy_admin/models/unset_killswitch_switch_response.rb', line 66

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
58
# File 'lib/shipeasy_admin/models/unset_killswitch_switch_response.rb', line 51

def self.attribute_map
  {
    :'id' => :'id',
    :'env' => :'env',
    :'switch_key' => :'switchKey',
    :'removed' => :'removed'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/shipeasy_admin/models/unset_killswitch_switch_response.rb', line 248

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/shipeasy_admin/models/unset_killswitch_switch_response.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



71
72
73
74
75
76
77
78
# File 'lib/shipeasy_admin/models/unset_killswitch_switch_response.rb', line 71

def self.openapi_types
  {
    :'id' => :'String',
    :'env' => :'Env',
    :'switch_key' => :'String',
    :'removed' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



224
225
226
227
228
229
230
231
# File 'lib/shipeasy_admin/models/unset_killswitch_switch_response.rb', line 224

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      env == o.env &&
      switch_key == o.switch_key &&
      removed == o.removed
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


235
236
237
# File 'lib/shipeasy_admin/models/unset_killswitch_switch_response.rb', line 235

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



241
242
243
# File 'lib/shipeasy_admin/models/unset_killswitch_switch_response.rb', line 241

def hash
  [id, env, switch_key, removed].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/shipeasy_admin/models/unset_killswitch_switch_response.rb', line 129

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @env.nil?
    invalid_properties.push('invalid value for "env", env cannot be nil.')
  end

  if @switch_key.nil?
    invalid_properties.push('invalid value for "switch_key", switch_key cannot be nil.')
  end

  if @switch_key.to_s.length > 64
    invalid_properties.push('invalid value for "switch_key", the character length must be smaller than or equal to 64.')
  end

  pattern = Regexp.new(/^[a-z0-9](?:[a-z0-9_-]*[a-z0-9])?$/)
  if @switch_key !~ pattern
    invalid_properties.push("invalid value for \"switch_key\", must conform to the pattern #{pattern}.")
  end

  if @removed.nil?
    invalid_properties.push('invalid value for "removed", removed cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/shipeasy_admin/models/unset_killswitch_switch_response.rb', line 270

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



162
163
164
165
166
167
168
169
170
171
# File 'lib/shipeasy_admin/models/unset_killswitch_switch_response.rb', line 162

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @env.nil?
  return false if @switch_key.nil?
  return false if @switch_key.to_s.length > 64
  return false if @switch_key !~ Regexp.new(/^[a-z0-9](?:[a-z0-9_-]*[a-z0-9])?$/)
  return false if @removed.nil?
  true
end