Class: Shipeasy::Admin::Generated::UpdateAlertRuleRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Shipeasy::Admin::Generated::UpdateAlertRuleRequest
- Defined in:
- lib/shipeasy_admin/models/update_alert_rule_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#comparator ⇒ Object
Returns the value of attribute comparator.
-
#enabled ⇒ Object
Returns the value of attribute enabled.
-
#name ⇒ Object
Returns the value of attribute name.
-
#notify ⇒ Object
Returns the value of attribute notify.
-
#severity ⇒ Object
Returns the value of attribute severity.
-
#threshold ⇒ Object
Minimum detectable effect (relative, 0–1) for power planning.
-
#window_hours ⇒ Object
Returns the value of attribute window_hours.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateAlertRuleRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateAlertRuleRequest
Initializes the object
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/shipeasy_admin/models/update_alert_rule_request.rb', line 101 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::UpdateAlertRuleRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::UpdateAlertRuleRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'comparator') self.comparator = attributes[:'comparator'] end if attributes.key?(:'threshold') self.threshold = attributes[:'threshold'] end if attributes.key?(:'window_hours') self.window_hours = attributes[:'window_hours'] end if attributes.key?(:'severity') self.severity = attributes[:'severity'] end if attributes.key?(:'enabled') self.enabled = attributes[:'enabled'] end if attributes.key?(:'notify') self.notify = attributes[:'notify'] end end |
Instance Attribute Details
#comparator ⇒ Object
Returns the value of attribute comparator.
20 21 22 |
# File 'lib/shipeasy_admin/models/update_alert_rule_request.rb', line 20 def comparator @comparator end |
#enabled ⇒ Object
Returns the value of attribute enabled.
29 30 31 |
# File 'lib/shipeasy_admin/models/update_alert_rule_request.rb', line 29 def enabled @enabled end |
#name ⇒ Object
Returns the value of attribute name.
18 19 20 |
# File 'lib/shipeasy_admin/models/update_alert_rule_request.rb', line 18 def name @name end |
#notify ⇒ Object
Returns the value of attribute notify.
31 32 33 |
# File 'lib/shipeasy_admin/models/update_alert_rule_request.rb', line 31 def notify @notify end |
#severity ⇒ Object
Returns the value of attribute severity.
27 28 29 |
# File 'lib/shipeasy_admin/models/update_alert_rule_request.rb', line 27 def severity @severity end |
#threshold ⇒ Object
Minimum detectable effect (relative, 0–1) for power planning. null to omit.
23 24 25 |
# File 'lib/shipeasy_admin/models/update_alert_rule_request.rb', line 23 def threshold @threshold end |
#window_hours ⇒ Object
Returns the value of attribute window_hours.
25 26 27 |
# File 'lib/shipeasy_admin/models/update_alert_rule_request.rb', line 25 def window_hours @window_hours end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
69 70 71 |
# File 'lib/shipeasy_admin/models/update_alert_rule_request.rb', line 69 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
74 75 76 |
# File 'lib/shipeasy_admin/models/update_alert_rule_request.rb', line 74 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/shipeasy_admin/models/update_alert_rule_request.rb', line 56 def self.attribute_map { :'name' => :'name', :'comparator' => :'comparator', :'threshold' => :'threshold', :'window_hours' => :'windowHours', :'severity' => :'severity', :'enabled' => :'enabled', :'notify' => :'notify' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/shipeasy_admin/models/update_alert_rule_request.rb', line 268 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
92 93 94 95 96 97 |
# File 'lib/shipeasy_admin/models/update_alert_rule_request.rb', line 92 def self.openapi_nullable Set.new([ :'threshold', :'notify' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/shipeasy_admin/models/update_alert_rule_request.rb', line 79 def self.openapi_types { :'name' => :'String', :'comparator' => :'String', :'threshold' => :'Float', :'window_hours' => :'Integer', :'severity' => :'String', :'enabled' => :'Boolean', :'notify' => :'ListAlertRulesResponseInnerNotify' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/shipeasy_admin/models/update_alert_rule_request.rb', line 241 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && comparator == o.comparator && threshold == o.threshold && window_hours == o.window_hours && severity == o.severity && enabled == o.enabled && notify == o.notify end |
#eql?(o) ⇒ Boolean
255 256 257 |
# File 'lib/shipeasy_admin/models/update_alert_rule_request.rb', line 255 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
261 262 263 |
# File 'lib/shipeasy_admin/models/update_alert_rule_request.rb', line 261 def hash [name, comparator, threshold, window_hours, severity, enabled, notify].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/shipeasy_admin/models/update_alert_rule_request.rb', line 146 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length > 120 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 120.') end if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if !@window_hours.nil? && @window_hours > 720 invalid_properties.push('invalid value for "window_hours", must be smaller than or equal to 720.') end if !@window_hours.nil? && @window_hours < 1 invalid_properties.push('invalid value for "window_hours", must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/shipeasy_admin/models/update_alert_rule_request.rb', line 290 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/shipeasy_admin/models/update_alert_rule_request.rb', line 170 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length > 120 return false if !@name.nil? && @name.to_s.length < 1 comparator_validator = EnumAttributeValidator.new('String', ["gt", "gte", "lt", "lte"]) return false unless comparator_validator.valid?(@comparator) return false if !@window_hours.nil? && @window_hours > 720 return false if !@window_hours.nil? && @window_hours < 1 severity_validator = EnumAttributeValidator.new('String', ["danger", "warn", "info"]) return false unless severity_validator.valid?(@severity) true end |