Class: Shipeasy::Admin::Generated::UpdateConfigRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Shipeasy::Admin::Generated::UpdateConfigRequest
- Defined in:
- lib/shipeasy_admin/models/update_config_request.rb
Overview
Body for PATCH /api/admin/configs/{id}. Partial — only supplied fields change. value republishes on every env.
Instance Attribute Summary collapse
-
#folder ⇒ Object
Optional folder name grouping items in the dashboard.
-
#schema ⇒ Object
Replacement schema.
-
#value ⇒ Object
Returns the value of attribute value.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateConfigRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateConfigRequest
Initializes the object
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/shipeasy_admin/models/update_config_request.rb', line 65 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::UpdateConfigRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::UpdateConfigRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'schema') if (value = attributes[:'schema']).is_a?(Hash) self.schema = value end end if attributes.key?(:'value') self.value = attributes[:'value'] end if attributes.key?(:'folder') self.folder = attributes[:'folder'] end end |
Instance Attribute Details
#folder ⇒ Object
Optional folder name grouping items in the dashboard. Alphanumeric, _ or - (no /). Part of the SDK lookup key (<folder>/<name>).
25 26 27 |
# File 'lib/shipeasy_admin/models/update_config_request.rb', line 25 def folder @folder end |
#schema ⇒ Object
Replacement schema. When supplied, the new schema is validated against every published value before it lands.
20 21 22 |
# File 'lib/shipeasy_admin/models/update_config_request.rb', line 20 def schema @schema end |
#value ⇒ Object
Returns the value of attribute value.
22 23 24 |
# File 'lib/shipeasy_admin/models/update_config_request.rb', line 22 def value @value end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
37 38 39 |
# File 'lib/shipeasy_admin/models/update_config_request.rb', line 37 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
42 43 44 |
# File 'lib/shipeasy_admin/models/update_config_request.rb', line 42 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 |
# File 'lib/shipeasy_admin/models/update_config_request.rb', line 28 def self.attribute_map { :'schema' => :'schema', :'value' => :'value', :'folder' => :'folder' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/shipeasy_admin/models/update_config_request.rb', line 160 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
56 57 58 59 60 61 |
# File 'lib/shipeasy_admin/models/update_config_request.rb', line 56 def self.openapi_nullable Set.new([ :'value', :'folder' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 |
# File 'lib/shipeasy_admin/models/update_config_request.rb', line 47 def self.openapi_types { :'schema' => :'Hash<String, Object>', :'value' => :'Object', :'folder' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
137 138 139 140 141 142 143 |
# File 'lib/shipeasy_admin/models/update_config_request.rb', line 137 def ==(o) return true if self.equal?(o) self.class == o.class && schema == o.schema && value == o.value && folder == o.folder end |
#eql?(o) ⇒ Boolean
147 148 149 |
# File 'lib/shipeasy_admin/models/update_config_request.rb', line 147 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
153 154 155 |
# File 'lib/shipeasy_admin/models/update_config_request.rb', line 153 def hash [schema, value, folder].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/shipeasy_admin/models/update_config_request.rb', line 96 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@folder.nil? && @folder.to_s.length > 256 invalid_properties.push('invalid value for "folder", the character length must be smaller than or equal to 256.') end pattern = Regexp.new(/^[a-zA-Z0-9_-]+$/) if !@folder.nil? && @folder !~ pattern invalid_properties.push("invalid value for \"folder\", must conform to the pattern #{pattern}.") end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/shipeasy_admin/models/update_config_request.rb', line 182 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
113 114 115 116 117 118 |
# File 'lib/shipeasy_admin/models/update_config_request.rb', line 113 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@folder.nil? && @folder.to_s.length > 256 return false if !@folder.nil? && @folder !~ Regexp.new(/^[a-zA-Z0-9_-]+$/) true end |