Class: Shipeasy::Admin::Generated::AttributesApi
- Inherits:
-
Object
- Object
- Shipeasy::Admin::Generated::AttributesApi
- Defined in:
- lib/shipeasy_admin/api/attributes_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ AttributesApi
constructor
A new instance of AttributesApi.
-
#list_attributes(opts = {}) ⇒ Array<ListAttributesResponseInner>
List targeting attributes Returns every auto-inferred targeting attribute in the project — the
nameand (when known) the valuetype— for building gate/experiment targeting rules. -
#list_attributes_with_http_info(opts = {}) ⇒ Array<(Array<ListAttributesResponseInner>, Integer, Hash)>
List targeting attributes Returns every auto-inferred targeting attribute in the project — the `name` and (when known) the value `type` — for building gate/experiment targeting rules.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ AttributesApi
Returns a new instance of AttributesApi.
19 20 21 |
# File 'lib/shipeasy_admin/api/attributes_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/shipeasy_admin/api/attributes_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#list_attributes(opts = {}) ⇒ Array<ListAttributesResponseInner>
List targeting attributes
Returns every auto-inferred targeting attribute in the project — the name and (when known) the value type — for building gate/experiment targeting rules. Use case: Discover which user-context keys are available before authoring a targeting rule, instead of guessing attribute names.
27 28 29 30 |
# File 'lib/shipeasy_admin/api/attributes_api.rb', line 27 def list_attributes(opts = {}) data, _status_code, _headers = list_attributes_with_http_info(opts) data end |
#list_attributes_with_http_info(opts = {}) ⇒ Array<(Array<ListAttributesResponseInner>, Integer, Hash)>
List targeting attributes Returns every auto-inferred targeting attribute in the project — the `name` and (when known) the value `type` — for building gate/experiment targeting rules. Use case: Discover which user-context keys are available before authoring a targeting rule, instead of guessing attribute names.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/shipeasy_admin/api/attributes_api.rb', line 37 def list_attributes_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AttributesApi.list_attributes ...' end # resource path local_var_path = '/api/admin/attributes' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'X-Project-Id'] = opts[:'x_project_id'] if !opts[:'x_project_id'].nil? # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Array<ListAttributesResponseInner>' # auth_names auth_names = opts[:debug_auth_names] || ['bearerSdkKey'] = opts.merge( :operation => :"AttributesApi.list_attributes", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AttributesApi#list_attributes\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |