Class: Shipeasy::Admin::Generated::CreateAlertRuleRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Shipeasy::Admin::Generated::CreateAlertRuleRequest
- Defined in:
- lib/shipeasy_admin/models/create_alert_rule_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#comparator ⇒ Object
How the metric value is compared to the threshold (gt/gte/lt/lte).
-
#enabled ⇒ Object
Whether the rule is evaluated by the cron.
-
#metric_id ⇒ Object
Id of the metric to evaluate.
-
#name ⇒ Object
Human label for the rule, shown on the alert and the rules list.
-
#notify ⇒ Object
Returns the value of attribute notify.
-
#severity ⇒ Object
Severity of the raised alert.
-
#threshold ⇒ Object
Threshold the metric value is compared against.
-
#window_hours ⇒ Object
Lookback window (hours) the metric is aggregated over.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateAlertRuleRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateAlertRuleRequest
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/shipeasy_admin/models/create_alert_rule_request.rb', line 110 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::CreateAlertRuleRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::CreateAlertRuleRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'metric_id') self.metric_id = attributes[:'metric_id'] else self.metric_id = nil end if attributes.key?(:'comparator') self.comparator = attributes[:'comparator'] else self.comparator = nil end if attributes.key?(:'threshold') self.threshold = attributes[:'threshold'] else self.threshold = nil end if attributes.key?(:'window_hours') self.window_hours = attributes[:'window_hours'] else self.window_hours = 24 end if attributes.key?(:'severity') self.severity = attributes[:'severity'] else self.severity = 'warn' end if attributes.key?(:'enabled') self.enabled = attributes[:'enabled'] else self.enabled = true end if attributes.key?(:'notify') self.notify = attributes[:'notify'] end end |
Instance Attribute Details
#comparator ⇒ Object
How the metric value is compared to the threshold (gt/gte/lt/lte).
25 26 27 |
# File 'lib/shipeasy_admin/models/create_alert_rule_request.rb', line 25 def comparator @comparator end |
#enabled ⇒ Object
Whether the rule is evaluated by the cron.
37 38 39 |
# File 'lib/shipeasy_admin/models/create_alert_rule_request.rb', line 37 def enabled @enabled end |
#metric_id ⇒ Object
Id of the metric to evaluate.
22 23 24 |
# File 'lib/shipeasy_admin/models/create_alert_rule_request.rb', line 22 def metric_id @metric_id end |
#name ⇒ Object
Human label for the rule, shown on the alert and the rules list.
19 20 21 |
# File 'lib/shipeasy_admin/models/create_alert_rule_request.rb', line 19 def name @name end |
#notify ⇒ Object
Returns the value of attribute notify.
39 40 41 |
# File 'lib/shipeasy_admin/models/create_alert_rule_request.rb', line 39 def notify @notify end |
#severity ⇒ Object
Severity of the raised alert.
34 35 36 |
# File 'lib/shipeasy_admin/models/create_alert_rule_request.rb', line 34 def severity @severity end |
#threshold ⇒ Object
Threshold the metric value is compared against.
28 29 30 |
# File 'lib/shipeasy_admin/models/create_alert_rule_request.rb', line 28 def threshold @threshold end |
#window_hours ⇒ Object
Lookback window (hours) the metric is aggregated over. 1–720.
31 32 33 |
# File 'lib/shipeasy_admin/models/create_alert_rule_request.rb', line 31 def window_hours @window_hours end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
78 79 80 |
# File 'lib/shipeasy_admin/models/create_alert_rule_request.rb', line 78 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
83 84 85 |
# File 'lib/shipeasy_admin/models/create_alert_rule_request.rb', line 83 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/shipeasy_admin/models/create_alert_rule_request.rb', line 64 def self.attribute_map { :'name' => :'name', :'metric_id' => :'metricId', :'comparator' => :'comparator', :'threshold' => :'threshold', :'window_hours' => :'windowHours', :'severity' => :'severity', :'enabled' => :'enabled', :'notify' => :'notify' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 |
# File 'lib/shipeasy_admin/models/create_alert_rule_request.rb', line 345 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
102 103 104 105 106 |
# File 'lib/shipeasy_admin/models/create_alert_rule_request.rb', line 102 def self.openapi_nullable Set.new([ :'notify' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/shipeasy_admin/models/create_alert_rule_request.rb', line 88 def self.openapi_types { :'name' => :'String', :'metric_id' => :'String', :'comparator' => :'String', :'threshold' => :'Float', :'window_hours' => :'Integer', :'severity' => :'String', :'enabled' => :'Boolean', :'notify' => :'NotificationTarget' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/shipeasy_admin/models/create_alert_rule_request.rb', line 317 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && metric_id == o.metric_id && comparator == o.comparator && threshold == o.threshold && window_hours == o.window_hours && severity == o.severity && enabled == o.enabled && notify == o.notify end |
#eql?(o) ⇒ Boolean
332 333 334 |
# File 'lib/shipeasy_admin/models/create_alert_rule_request.rb', line 332 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
338 339 340 |
# File 'lib/shipeasy_admin/models/create_alert_rule_request.rb', line 338 def hash [name, metric_id, comparator, threshold, window_hours, severity, enabled, notify].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/shipeasy_admin/models/create_alert_rule_request.rb', line 173 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 120 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 120.') end if @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end if @metric_id.nil? invalid_properties.push('invalid value for "metric_id", metric_id cannot be nil.') end if @metric_id.to_s.length < 1 invalid_properties.push('invalid value for "metric_id", the character length must be greater than or equal to 1.') end if @comparator.nil? invalid_properties.push('invalid value for "comparator", comparator cannot be nil.') end if @threshold.nil? invalid_properties.push('invalid value for "threshold", threshold cannot be nil.') end if !@window_hours.nil? && @window_hours > 720 invalid_properties.push('invalid value for "window_hours", must be smaller than or equal to 720.') end if !@window_hours.nil? && @window_hours < 1 invalid_properties.push('invalid value for "window_hours", must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
367 368 369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/shipeasy_admin/models/create_alert_rule_request.rb', line 367 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/shipeasy_admin/models/create_alert_rule_request.rb', line 217 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length > 120 return false if @name.to_s.length < 1 return false if @metric_id.nil? return false if @metric_id.to_s.length < 1 return false if @comparator.nil? comparator_validator = EnumAttributeValidator.new('String', ["gt", "gte", "lt", "lte"]) return false unless comparator_validator.valid?(@comparator) return false if @threshold.nil? return false if !@window_hours.nil? && @window_hours > 720 return false if !@window_hours.nil? && @window_hours < 1 severity_validator = EnumAttributeValidator.new('String', ["danger", "warn", "info"]) return false unless severity_validator.valid?(@severity) true end |