Class: Shipeasy::Admin::Generated::CreateMetricRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Shipeasy::Admin::Generated::CreateMetricRequest
- Defined in:
- lib/shipeasy_admin/models/create_metric_request.rb
Overview
Body for POST /api/admin/metrics. Requires name, event_name, and exactly one of query / query_ir.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#direction ⇒ Object
Desired direction of movement.
-
#event_name ⇒ Object
Source event the query reads from.
-
#folder ⇒ Object
Optional folder name grouping items in the dashboard.
-
#min_detectable_effect ⇒ Object
Minimum detectable effect (relative, 0–1) for power planning.
-
#name ⇒ Object
Stable metric key.
-
#query ⇒ Object
Metric query DSL string, e.g.
-
#query_ir ⇒ Object
Returns the value of attribute query_ir.
-
#winsorize_pct ⇒ Object
Winsorise percentile (1–99) to clamp outliers.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateMetricRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateMetricRequest
Initializes the object
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/shipeasy_admin/models/create_metric_request.rb', line 112 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::CreateMetricRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::CreateMetricRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'folder') self.folder = attributes[:'folder'] end if attributes.key?(:'event_name') self.event_name = attributes[:'event_name'] else self.event_name = nil end if attributes.key?(:'query') self.query = attributes[:'query'] end if attributes.key?(:'query_ir') self.query_ir = attributes[:'query_ir'] end if attributes.key?(:'winsorize_pct') self.winsorize_pct = attributes[:'winsorize_pct'] else self.winsorize_pct = 99 end if attributes.key?(:'min_detectable_effect') self.min_detectable_effect = attributes[:'min_detectable_effect'] end if attributes.key?(:'direction') self.direction = attributes[:'direction'] else self.direction = 'higher_better' end end |
Instance Attribute Details
#direction ⇒ Object
Desired direction of movement. higher_better (default), lower_better, or neutral (guardrail).
40 41 42 |
# File 'lib/shipeasy_admin/models/create_metric_request.rb', line 40 def direction @direction end |
#event_name ⇒ Object
Source event the query reads from.
26 27 28 |
# File 'lib/shipeasy_admin/models/create_metric_request.rb', line 26 def event_name @event_name end |
#folder ⇒ Object
Optional folder name grouping items in the dashboard. Alphanumeric, _ or - (no /). Part of the SDK lookup key (<folder>/<name>).
23 24 25 |
# File 'lib/shipeasy_admin/models/create_metric_request.rb', line 23 def folder @folder end |
#min_detectable_effect ⇒ Object
Minimum detectable effect (relative, 0–1) for power planning. null to omit.
37 38 39 |
# File 'lib/shipeasy_admin/models/create_metric_request.rb', line 37 def min_detectable_effect @min_detectable_effect end |
#name ⇒ Object
Stable metric key. Single segment or folder.name; lowercase letters, digits, _/-; max 128 chars.
20 21 22 |
# File 'lib/shipeasy_admin/models/create_metric_request.rb', line 20 def name @name end |
#query ⇒ Object
Metric query DSL string, e.g. sum(purchase, amount). Provide this OR query_ir.
29 30 31 |
# File 'lib/shipeasy_admin/models/create_metric_request.rb', line 29 def query @query end |
#query_ir ⇒ Object
Returns the value of attribute query_ir.
31 32 33 |
# File 'lib/shipeasy_admin/models/create_metric_request.rb', line 31 def query_ir @query_ir end |
#winsorize_pct ⇒ Object
Winsorise percentile (1–99) to clamp outliers. Defaults to 99.
34 35 36 |
# File 'lib/shipeasy_admin/models/create_metric_request.rb', line 34 def winsorize_pct @winsorize_pct end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
79 80 81 |
# File 'lib/shipeasy_admin/models/create_metric_request.rb', line 79 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
84 85 86 |
# File 'lib/shipeasy_admin/models/create_metric_request.rb', line 84 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/shipeasy_admin/models/create_metric_request.rb', line 65 def self.attribute_map { :'name' => :'name', :'folder' => :'folder', :'event_name' => :'event_name', :'query' => :'query', :'query_ir' => :'query_ir', :'winsorize_pct' => :'winsorize_pct', :'min_detectable_effect' => :'min_detectable_effect', :'direction' => :'direction' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/shipeasy_admin/models/create_metric_request.rb', line 365 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
103 104 105 106 107 108 |
# File 'lib/shipeasy_admin/models/create_metric_request.rb', line 103 def self.openapi_nullable Set.new([ :'folder', :'min_detectable_effect', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/shipeasy_admin/models/create_metric_request.rb', line 89 def self.openapi_types { :'name' => :'String', :'folder' => :'String', :'event_name' => :'String', :'query' => :'String', :'query_ir' => :'ListMetricsResponseInnerQueryIr', :'winsorize_pct' => :'Integer', :'min_detectable_effect' => :'Float', :'direction' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/shipeasy_admin/models/create_metric_request.rb', line 337 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && folder == o.folder && event_name == o.event_name && query == o.query && query_ir == o.query_ir && winsorize_pct == o.winsorize_pct && min_detectable_effect == o.min_detectable_effect && direction == o.direction end |
#eql?(o) ⇒ Boolean
352 353 354 |
# File 'lib/shipeasy_admin/models/create_metric_request.rb', line 352 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
358 359 360 |
# File 'lib/shipeasy_admin/models/create_metric_request.rb', line 358 def hash [name, folder, event_name, query, query_ir, winsorize_pct, min_detectable_effect, direction].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/shipeasy_admin/models/create_metric_request.rb', line 169 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 128 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 128.') end pattern = Regexp.new(/^[a-z0-9](?:[a-z0-9_-]*[a-z0-9])?(?:\.[a-z0-9](?:[a-z0-9_-]*[a-z0-9])?)?$/) if @name !~ pattern invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.") end if !@folder.nil? && @folder.to_s.length > 256 invalid_properties.push('invalid value for "folder", the character length must be smaller than or equal to 256.') end pattern = Regexp.new(/^[a-zA-Z0-9_-]+$/) if !@folder.nil? && @folder !~ pattern invalid_properties.push("invalid value for \"folder\", must conform to the pattern #{pattern}.") end if @event_name.nil? invalid_properties.push('invalid value for "event_name", event_name cannot be nil.') end if @event_name.to_s.length < 1 invalid_properties.push('invalid value for "event_name", the character length must be greater than or equal to 1.') end if !@query.nil? && @query.to_s.length > 4096 invalid_properties.push('invalid value for "query", the character length must be smaller than or equal to 4096.') end if !@query.nil? && @query.to_s.length < 1 invalid_properties.push('invalid value for "query", the character length must be greater than or equal to 1.') end if !@winsorize_pct.nil? && @winsorize_pct > 99 invalid_properties.push('invalid value for "winsorize_pct", must be smaller than or equal to 99.') end if !@winsorize_pct.nil? && @winsorize_pct < 1 invalid_properties.push('invalid value for "winsorize_pct", must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
387 388 389 390 391 392 393 394 395 396 397 398 399 |
# File 'lib/shipeasy_admin/models/create_metric_request.rb', line 387 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/shipeasy_admin/models/create_metric_request.rb', line 223 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @name.to_s.length > 128 return false if @name !~ Regexp.new(/^[a-z0-9](?:[a-z0-9_-]*[a-z0-9])?(?:\.[a-z0-9](?:[a-z0-9_-]*[a-z0-9])?)?$/) return false if !@folder.nil? && @folder.to_s.length > 256 return false if !@folder.nil? && @folder !~ Regexp.new(/^[a-zA-Z0-9_-]+$/) return false if @event_name.nil? return false if @event_name.to_s.length < 1 return false if !@query.nil? && @query.to_s.length > 4096 return false if !@query.nil? && @query.to_s.length < 1 return false if !@winsorize_pct.nil? && @winsorize_pct > 99 return false if !@winsorize_pct.nil? && @winsorize_pct < 1 direction_validator = EnumAttributeValidator.new('String', ["higher_better", "lower_better", "neutral"]) return false unless direction_validator.valid?(@direction) true end |