Class: Shipeasy::Admin::Generated::CreatePublicBugRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Shipeasy::Admin::Generated::CreatePublicBugRequest
- Defined in:
- lib/shipeasy_admin/models/create_public_bug_request.rb
Overview
Body for POST /ops/bug. The same bug fields as CreateBugRequest, minus the type discriminator — the path already says what is being filed.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#actual_result ⇒ Object
What actually happened.
-
#assignee_id ⇒ Object
The
users.idof the person to assign as owner at creation, ornull. -
#context ⇒ Object
Arbitrary capture context, or
null. -
#expected_result ⇒ Object
What was expected instead.
-
#notify ⇒ Object
Where this bug's completion notification lands.
-
#page_url ⇒ Object
URL of the page the bug relates to, or
null. -
#priority ⇒ Object
Initial triage priority, or
null. -
#reporter_email ⇒ Object
Email of the reporter, or
null. -
#status ⇒ Object
Initial lifecycle status; defaults to
openwhen omitted. -
#steps_to_reproduce ⇒ Object
How to reproduce the bug.
-
#subscribers ⇒ Object
Emails of teammates to subscribe to this item's Slack pings at creation.
-
#tags ⇒ Object
Tag names to attach at creation (get-or-created by name, deduped case-insensitively).
-
#title ⇒ Object
One-line bug title (no leading/trailing whitespace).
-
#user_agent ⇒ Object
Reporter's user-agent string, or
null. -
#viewport ⇒ Object
Reporter's viewport (e.g.
1280x720), ornull.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreatePublicBugRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreatePublicBugRequest
Initializes the object
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/shipeasy_admin/models/create_public_bug_request.rb', line 154 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::CreatePublicBugRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::CreatePublicBugRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'title') self.title = attributes[:'title'] else self.title = nil end if attributes.key?(:'steps_to_reproduce') self.steps_to_reproduce = attributes[:'steps_to_reproduce'] else self.steps_to_reproduce = '' end if attributes.key?(:'actual_result') self.actual_result = attributes[:'actual_result'] else self.actual_result = '' end if attributes.key?(:'expected_result') self.expected_result = attributes[:'expected_result'] else self.expected_result = '' end if attributes.key?(:'priority') self.priority = attributes[:'priority'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'assignee_id') self.assignee_id = attributes[:'assignee_id'] end if attributes.key?(:'subscribers') if (value = attributes[:'subscribers']).is_a?(Array) self.subscribers = value end end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'reporter_email') self.reporter_email = attributes[:'reporter_email'] end if attributes.key?(:'page_url') self.page_url = attributes[:'page_url'] end if attributes.key?(:'user_agent') self.user_agent = attributes[:'user_agent'] end if attributes.key?(:'viewport') self. = attributes[:'viewport'] end if attributes.key?(:'context') if (value = attributes[:'context']).is_a?(Hash) self.context = value end end if attributes.key?(:'notify') self.notify = attributes[:'notify'] end end |
Instance Attribute Details
#actual_result ⇒ Object
What actually happened.
26 27 28 |
# File 'lib/shipeasy_admin/models/create_public_bug_request.rb', line 26 def actual_result @actual_result end |
#assignee_id ⇒ Object
The users.id of the person to assign as owner at creation, or null.
38 39 40 |
# File 'lib/shipeasy_admin/models/create_public_bug_request.rb', line 38 def assignee_id @assignee_id end |
#context ⇒ Object
Arbitrary capture context, or null.
59 60 61 |
# File 'lib/shipeasy_admin/models/create_public_bug_request.rb', line 59 def context @context end |
#expected_result ⇒ Object
What was expected instead.
29 30 31 |
# File 'lib/shipeasy_admin/models/create_public_bug_request.rb', line 29 def expected_result @expected_result end |
#notify ⇒ Object
Where this bug's completion notification lands.
62 63 64 |
# File 'lib/shipeasy_admin/models/create_public_bug_request.rb', line 62 def notify @notify end |
#page_url ⇒ Object
URL of the page the bug relates to, or null.
50 51 52 |
# File 'lib/shipeasy_admin/models/create_public_bug_request.rb', line 50 def page_url @page_url end |
#priority ⇒ Object
Initial triage priority, or null.
32 33 34 |
# File 'lib/shipeasy_admin/models/create_public_bug_request.rb', line 32 def priority @priority end |
#reporter_email ⇒ Object
Email of the reporter, or null.
47 48 49 |
# File 'lib/shipeasy_admin/models/create_public_bug_request.rb', line 47 def reporter_email @reporter_email end |
#status ⇒ Object
Initial lifecycle status; defaults to open when omitted.
35 36 37 |
# File 'lib/shipeasy_admin/models/create_public_bug_request.rb', line 35 def status @status end |
#steps_to_reproduce ⇒ Object
How to reproduce the bug.
23 24 25 |
# File 'lib/shipeasy_admin/models/create_public_bug_request.rb', line 23 def steps_to_reproduce @steps_to_reproduce end |
#subscribers ⇒ Object
Emails of teammates to subscribe to this item's Slack pings at creation.
41 42 43 |
# File 'lib/shipeasy_admin/models/create_public_bug_request.rb', line 41 def subscribers @subscribers end |
#tags ⇒ Object
Tag names to attach at creation (get-or-created by name, deduped case-insensitively).
44 45 46 |
# File 'lib/shipeasy_admin/models/create_public_bug_request.rb', line 44 def @tags end |
#title ⇒ Object
One-line bug title (no leading/trailing whitespace).
20 21 22 |
# File 'lib/shipeasy_admin/models/create_public_bug_request.rb', line 20 def title @title end |
#user_agent ⇒ Object
Reporter's user-agent string, or null.
53 54 55 |
# File 'lib/shipeasy_admin/models/create_public_bug_request.rb', line 53 def user_agent @user_agent end |
#viewport ⇒ Object
Reporter's viewport (e.g. 1280x720), or null.
56 57 58 |
# File 'lib/shipeasy_admin/models/create_public_bug_request.rb', line 56 def @viewport end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
108 109 110 |
# File 'lib/shipeasy_admin/models/create_public_bug_request.rb', line 108 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
113 114 115 |
# File 'lib/shipeasy_admin/models/create_public_bug_request.rb', line 113 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/shipeasy_admin/models/create_public_bug_request.rb', line 87 def self.attribute_map { :'title' => :'title', :'steps_to_reproduce' => :'stepsToReproduce', :'actual_result' => :'actualResult', :'expected_result' => :'expectedResult', :'priority' => :'priority', :'status' => :'status', :'assignee_id' => :'assigneeId', :'subscribers' => :'subscribers', :'tags' => :'tags', :'reporter_email' => :'reporterEmail', :'page_url' => :'pageUrl', :'user_agent' => :'userAgent', :'viewport' => :'viewport', :'context' => :'context', :'notify' => :'notify' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 |
# File 'lib/shipeasy_admin/models/create_public_bug_request.rb', line 426 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/shipeasy_admin/models/create_public_bug_request.rb', line 139 def self.openapi_nullable Set.new([ :'priority', :'assignee_id', :'reporter_email', :'page_url', :'user_agent', :'viewport', :'context', :'notify' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/shipeasy_admin/models/create_public_bug_request.rb', line 118 def self.openapi_types { :'title' => :'String', :'steps_to_reproduce' => :'String', :'actual_result' => :'String', :'expected_result' => :'String', :'priority' => :'OpsItemPriority', :'status' => :'OpsItemStatus', :'assignee_id' => :'String', :'subscribers' => :'Array<String>', :'tags' => :'Array<String>', :'reporter_email' => :'String', :'page_url' => :'String', :'user_agent' => :'String', :'viewport' => :'String', :'context' => :'Hash<String, Object>', :'notify' => :'NotificationTarget' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 |
# File 'lib/shipeasy_admin/models/create_public_bug_request.rb', line 391 def ==(o) return true if self.equal?(o) self.class == o.class && title == o.title && steps_to_reproduce == o.steps_to_reproduce && actual_result == o.actual_result && expected_result == o.expected_result && priority == o.priority && status == o.status && assignee_id == o.assignee_id && subscribers == o.subscribers && == o. && reporter_email == o.reporter_email && page_url == o.page_url && user_agent == o.user_agent && == o. && context == o.context && notify == o.notify end |
#eql?(o) ⇒ Boolean
413 414 415 |
# File 'lib/shipeasy_admin/models/create_public_bug_request.rb', line 413 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
419 420 421 |
# File 'lib/shipeasy_admin/models/create_public_bug_request.rb', line 419 def hash [title, steps_to_reproduce, actual_result, expected_result, priority, status, assignee_id, subscribers, , reporter_email, page_url, user_agent, , context, notify].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/shipeasy_admin/models/create_public_bug_request.rb', line 245 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @title.nil? invalid_properties.push('invalid value for "title", title cannot be nil.') end if @title.to_s.length > 200 invalid_properties.push('invalid value for "title", the character length must be smaller than or equal to 200.') end if @title.to_s.length < 1 invalid_properties.push('invalid value for "title", the character length must be greater than or equal to 1.') end pattern = Regexp.new(/^\S(.*\S)?$/) if @title !~ pattern invalid_properties.push("invalid value for \"title\", must conform to the pattern #{pattern}.") end if !@steps_to_reproduce.nil? && @steps_to_reproduce.to_s.length > 8000 invalid_properties.push('invalid value for "steps_to_reproduce", the character length must be smaller than or equal to 8000.') end if !@actual_result.nil? && @actual_result.to_s.length > 8000 invalid_properties.push('invalid value for "actual_result", the character length must be smaller than or equal to 8000.') end if !@expected_result.nil? && @expected_result.to_s.length > 8000 invalid_properties.push('invalid value for "expected_result", the character length must be smaller than or equal to 8000.') end if !@user_agent.nil? && @user_agent.to_s.length > 500 invalid_properties.push('invalid value for "user_agent", the character length must be smaller than or equal to 500.') end if !@viewport.nil? && @viewport.to_s.length > 40 invalid_properties.push('invalid value for "viewport", the character length must be smaller than or equal to 40.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
448 449 450 451 452 453 454 455 456 457 458 459 460 |
# File 'lib/shipeasy_admin/models/create_public_bug_request.rb', line 448 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/shipeasy_admin/models/create_public_bug_request.rb', line 290 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @title.nil? return false if @title.to_s.length > 200 return false if @title.to_s.length < 1 return false if @title !~ Regexp.new(/^\S(.*\S)?$/) return false if !@steps_to_reproduce.nil? && @steps_to_reproduce.to_s.length > 8000 return false if !@actual_result.nil? && @actual_result.to_s.length > 8000 return false if !@expected_result.nil? && @expected_result.to_s.length > 8000 return false if !@user_agent.nil? && @user_agent.to_s.length > 500 return false if !@viewport.nil? && @viewport.to_s.length > 40 true end |