Class: Shipeasy::Admin::Generated::ExperimentInlineMetric
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Shipeasy::Admin::Generated::ExperimentInlineMetric
- Defined in:
- lib/shipeasy_admin/models/experiment_inline_metric.rb
Overview
Inline metric — a DSL query, or an event (+ aggregation/value) the server compiles into one.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#aggregation ⇒ Object
Reducer for the
eventform. -
#event ⇒ Object
Event name to build the metric from server-side.
-
#name ⇒ Object
Stable metric key.
-
#query ⇒ Object
Metric DSL string.
-
#value ⇒ Object
Numeric event property for
sum/avg(withevent).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ExperimentInlineMetric
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ExperimentInlineMetric
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/shipeasy_admin/models/experiment_inline_metric.rb', line 96 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::ExperimentInlineMetric` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::ExperimentInlineMetric`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'query') self.query = attributes[:'query'] end if attributes.key?(:'event') self.event = attributes[:'event'] end if attributes.key?(:'aggregation') self.aggregation = attributes[:'aggregation'] end if attributes.key?(:'value') self.value = attributes[:'value'] end end |
Instance Attribute Details
#aggregation ⇒ Object
Reducer for the event form. Defaults to count_users.
29 30 31 |
# File 'lib/shipeasy_admin/models/experiment_inline_metric.rb', line 29 def aggregation @aggregation end |
#event ⇒ Object
Event name to build the metric from server-side. Auto-created if missing.
26 27 28 |
# File 'lib/shipeasy_admin/models/experiment_inline_metric.rb', line 26 def event @event end |
#name ⇒ Object
Stable metric key. Single segment or folder.name; lowercase letters, digits, _/-; max 128 chars.
20 21 22 |
# File 'lib/shipeasy_admin/models/experiment_inline_metric.rb', line 20 def name @name end |
#query ⇒ Object
Metric DSL string. Provide this OR event.
23 24 25 |
# File 'lib/shipeasy_admin/models/experiment_inline_metric.rb', line 23 def query @query end |
#value ⇒ Object
Numeric event property for sum/avg (with event).
32 33 34 |
# File 'lib/shipeasy_admin/models/experiment_inline_metric.rb', line 32 def value @value end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
68 69 70 |
# File 'lib/shipeasy_admin/models/experiment_inline_metric.rb', line 68 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
73 74 75 |
# File 'lib/shipeasy_admin/models/experiment_inline_metric.rb', line 73 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 |
# File 'lib/shipeasy_admin/models/experiment_inline_metric.rb', line 57 def self.attribute_map { :'name' => :'name', :'query' => :'query', :'event' => :'event', :'aggregation' => :'aggregation', :'value' => :'value' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/shipeasy_admin/models/experiment_inline_metric.rb', line 299 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
89 90 91 92 |
# File 'lib/shipeasy_admin/models/experiment_inline_metric.rb', line 89 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 |
# File 'lib/shipeasy_admin/models/experiment_inline_metric.rb', line 78 def self.openapi_types { :'name' => :'String', :'query' => :'String', :'event' => :'String', :'aggregation' => :'String', :'value' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
274 275 276 277 278 279 280 281 282 |
# File 'lib/shipeasy_admin/models/experiment_inline_metric.rb', line 274 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && query == o.query && event == o.event && aggregation == o.aggregation && value == o.value end |
#eql?(o) ⇒ Boolean
286 287 288 |
# File 'lib/shipeasy_admin/models/experiment_inline_metric.rb', line 286 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
292 293 294 |
# File 'lib/shipeasy_admin/models/experiment_inline_metric.rb', line 292 def hash [name, query, event, aggregation, value].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/shipeasy_admin/models/experiment_inline_metric.rb', line 133 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@name.nil? && @name.to_s.length > 128 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 128.') end pattern = Regexp.new(/^[a-z0-9](?:[a-z0-9_-]*[a-z0-9])?(?:\.[a-z0-9](?:[a-z0-9_-]*[a-z0-9])?)?$/) if !@name.nil? && @name !~ pattern invalid_properties.push("invalid value for \"name\", must conform to the pattern #{pattern}.") end if !@query.nil? && @query.to_s.length > 4096 invalid_properties.push('invalid value for "query", the character length must be smaller than or equal to 4096.') end if !@query.nil? && @query.to_s.length < 1 invalid_properties.push('invalid value for "query", the character length must be greater than or equal to 1.') end if !@event.nil? && @event.to_s.length > 256 invalid_properties.push('invalid value for "event", the character length must be smaller than or equal to 256.') end if !@event.nil? && @event.to_s.length < 1 invalid_properties.push('invalid value for "event", the character length must be greater than or equal to 1.') end if !@value.nil? && @value.to_s.length > 256 invalid_properties.push('invalid value for "value", the character length must be smaller than or equal to 256.') end if !@value.nil? && @value.to_s.length < 1 invalid_properties.push('invalid value for "value", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/shipeasy_admin/models/experiment_inline_metric.rb', line 321 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/shipeasy_admin/models/experiment_inline_metric.rb', line 174 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@name.nil? && @name.to_s.length > 128 return false if !@name.nil? && @name !~ Regexp.new(/^[a-z0-9](?:[a-z0-9_-]*[a-z0-9])?(?:\.[a-z0-9](?:[a-z0-9_-]*[a-z0-9])?)?$/) return false if !@query.nil? && @query.to_s.length > 4096 return false if !@query.nil? && @query.to_s.length < 1 return false if !@event.nil? && @event.to_s.length > 256 return false if !@event.nil? && @event.to_s.length < 1 aggregation_validator = EnumAttributeValidator.new('String', ["count_users", "count_events", "retention_7d", "retention_30d", "sum", "avg"]) return false unless aggregation_validator.valid?(@aggregation) return false if !@value.nil? && @value.to_s.length > 256 return false if !@value.nil? && @value.to_s.length < 1 true end |