Class: Shipeasy::Admin::Generated::ListConfigsResponseDataInner
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Shipeasy::Admin::Generated::ListConfigsResponseDataInner
- Defined in:
- lib/shipeasy_admin/models/list_configs_response_data_inner.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
Returns the value of attribute description.
-
#draft_values ⇒ Object
Per-env draft values (only returned by
GET /{id}). -
#drafts ⇒ Object
Per-env active drafts (if any).
-
#envs ⇒ Object
Per-env latest published version metadata.
-
#id ⇒ Object
Stable opaque config id (
cfg_…). -
#name ⇒ Object
Stable config key in
folder.nameform (two lowercase segments separated by a dot, e.g.pricing.tiers). -
#schema ⇒ Object
JSON Schema (draft 2020-12) describing the shape of the config value.
-
#updated_at ⇒ Object
ISO-8601 timestamp of last mutation.
-
#values ⇒ Object
Per-env latest published values (only returned by
GET /{id}, not list).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListConfigsResponseDataInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListConfigsResponseDataInner
Initializes the object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/shipeasy_admin/models/list_configs_response_data_inner.rb', line 93 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::ListConfigsResponseDataInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::ListConfigsResponseDataInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = nil end if attributes.key?(:'schema') if (value = attributes[:'schema']).is_a?(Hash) self.schema = value end else self.schema = nil end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] else self.updated_at = nil end if attributes.key?(:'envs') if (value = attributes[:'envs']).is_a?(Hash) self.envs = value end else self.envs = nil end if attributes.key?(:'drafts') if (value = attributes[:'drafts']).is_a?(Hash) self.drafts = value end else self.drafts = nil end if attributes.key?(:'values') if (value = attributes[:'values']).is_a?(Hash) self.values = value end end if attributes.key?(:'draft_values') if (value = attributes[:'draft_values']).is_a?(Hash) self.draft_values = value end end end |
Instance Attribute Details
#description ⇒ Object
Returns the value of attribute description.
24 25 26 |
# File 'lib/shipeasy_admin/models/list_configs_response_data_inner.rb', line 24 def description @description end |
#draft_values ⇒ Object
Per-env draft values (only returned by GET /{id}).
42 43 44 |
# File 'lib/shipeasy_admin/models/list_configs_response_data_inner.rb', line 42 def draft_values @draft_values end |
#drafts ⇒ Object
Per-env active drafts (if any).
36 37 38 |
# File 'lib/shipeasy_admin/models/list_configs_response_data_inner.rb', line 36 def drafts @drafts end |
#envs ⇒ Object
Per-env latest published version metadata.
33 34 35 |
# File 'lib/shipeasy_admin/models/list_configs_response_data_inner.rb', line 33 def envs @envs end |
#id ⇒ Object
Stable opaque config id (cfg_…).
19 20 21 |
# File 'lib/shipeasy_admin/models/list_configs_response_data_inner.rb', line 19 def id @id end |
#name ⇒ Object
Stable config key in folder.name form (two lowercase segments separated by a dot, e.g. pricing.tiers). Used by SDKs as Shipeasy.getConfig('<name>'). Immutable after create.
22 23 24 |
# File 'lib/shipeasy_admin/models/list_configs_response_data_inner.rb', line 22 def name @name end |
#schema ⇒ Object
JSON Schema (draft 2020-12) describing the shape of the config value. Top-level type must be 'object'; every published value is validated against this schema.
27 28 29 |
# File 'lib/shipeasy_admin/models/list_configs_response_data_inner.rb', line 27 def schema @schema end |
#updated_at ⇒ Object
ISO-8601 timestamp of last mutation.
30 31 32 |
# File 'lib/shipeasy_admin/models/list_configs_response_data_inner.rb', line 30 def updated_at @updated_at end |
#values ⇒ Object
Per-env latest published values (only returned by GET /{id}, not list).
39 40 41 |
# File 'lib/shipeasy_admin/models/list_configs_response_data_inner.rb', line 39 def values @values end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
60 61 62 |
# File 'lib/shipeasy_admin/models/list_configs_response_data_inner.rb', line 60 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
65 66 67 |
# File 'lib/shipeasy_admin/models/list_configs_response_data_inner.rb', line 65 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/shipeasy_admin/models/list_configs_response_data_inner.rb', line 45 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'description' => :'description', :'schema' => :'schema', :'updated_at' => :'updatedAt', :'envs' => :'envs', :'drafts' => :'drafts', :'values' => :'values', :'draft_values' => :'draftValues' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 |
# File 'lib/shipeasy_admin/models/list_configs_response_data_inner.rb', line 313 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
85 86 87 88 89 |
# File 'lib/shipeasy_admin/models/list_configs_response_data_inner.rb', line 85 def self.openapi_nullable Set.new([ :'description', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/shipeasy_admin/models/list_configs_response_data_inner.rb', line 70 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'description' => :'String', :'schema' => :'Hash<String, Object>', :'updated_at' => :'String', :'envs' => :'Hash<String, ListConfigsResponseDataInnerEnvsValue>', :'drafts' => :'Hash<String, ListConfigsResponseDataInnerDraftsValue>', :'values' => :'Hash<String, Object>', :'draft_values' => :'Hash<String, Object>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/shipeasy_admin/models/list_configs_response_data_inner.rb', line 284 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && description == o.description && schema == o.schema && updated_at == o.updated_at && envs == o.envs && drafts == o.drafts && values == o.values && draft_values == o.draft_values end |
#eql?(o) ⇒ Boolean
300 301 302 |
# File 'lib/shipeasy_admin/models/list_configs_response_data_inner.rb', line 300 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
306 307 308 |
# File 'lib/shipeasy_admin/models/list_configs_response_data_inner.rb', line 306 def hash [id, name, description, schema, updated_at, envs, drafts, values, draft_values].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/shipeasy_admin/models/list_configs_response_data_inner.rb', line 170 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 128 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 128.') end if @schema.nil? invalid_properties.push('invalid value for "schema", schema cannot be nil.') end if @updated_at.nil? invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.') end if @envs.nil? invalid_properties.push('invalid value for "envs", envs cannot be nil.') end if @drafts.nil? invalid_properties.push('invalid value for "drafts", drafts cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
335 336 337 338 339 340 341 342 343 344 345 346 347 |
# File 'lib/shipeasy_admin/models/list_configs_response_data_inner.rb', line 335 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/shipeasy_admin/models/list_configs_response_data_inner.rb', line 206 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @name.nil? return false if @name.to_s.length > 128 return false if @schema.nil? return false if @updated_at.nil? return false if @envs.nil? return false if @drafts.nil? true end |