Class: Shipeasy::Admin::Generated::ListMetricsResponseInnerQueryIr
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Shipeasy::Admin::Generated::ListMetricsResponseInnerQueryIr
- Defined in:
- lib/shipeasy_admin/models/list_metrics_response_inner_query_ir.rb
Overview
Typed query IR stored for the metric.
Instance Attribute Summary collapse
-
#agg ⇒ Object
Returns the value of attribute agg.
-
#filters ⇒ Object
Label filters on the event.
-
#group_by ⇒ Object
Returns the value of attribute group_by.
-
#metric ⇒ Object
Source event name (must equal
event_name). -
#value_label ⇒ Object
Numeric property summed/averaged for
sum/avg/quantile aggregations.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListMetricsResponseInnerQueryIr
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListMetricsResponseInnerQueryIr
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir.rb', line 72 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::ListMetricsResponseInnerQueryIr` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::ListMetricsResponseInnerQueryIr`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'agg') self.agg = attributes[:'agg'] else self.agg = nil end if attributes.key?(:'metric') self.metric = attributes[:'metric'] else self.metric = nil end if attributes.key?(:'value_label') self.value_label = attributes[:'value_label'] end if attributes.key?(:'filters') if (value = attributes[:'filters']).is_a?(Array) self.filters = value end end if attributes.key?(:'group_by') self.group_by = attributes[:'group_by'] end end |
Instance Attribute Details
#agg ⇒ Object
Returns the value of attribute agg.
19 20 21 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir.rb', line 19 def agg @agg end |
#filters ⇒ Object
Label filters on the event.
28 29 30 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir.rb', line 28 def filters @filters end |
#group_by ⇒ Object
Returns the value of attribute group_by.
30 31 32 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir.rb', line 30 def group_by @group_by end |
#metric ⇒ Object
Source event name (must equal event_name).
22 23 24 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir.rb', line 22 def metric @metric end |
#value_label ⇒ Object
Numeric property summed/averaged for sum/avg/quantile aggregations.
25 26 27 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir.rb', line 25 def value_label @value_label end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
44 45 46 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir.rb', line 44 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
49 50 51 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir.rb', line 49 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir.rb', line 33 def self.attribute_map { :'agg' => :'agg', :'metric' => :'metric', :'value_label' => :'valueLabel', :'filters' => :'filters', :'group_by' => :'groupBy' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir.rb', line 250 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
65 66 67 68 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir.rb', line 65 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir.rb', line 54 def self.openapi_types { :'agg' => :'ListMetricsResponseInnerQueryIrAgg', :'metric' => :'String', :'value_label' => :'String', :'filters' => :'Array<ListMetricsResponseInnerQueryIrAggOneOf9NumeratorFiltersInner>', :'group_by' => :'ListMetricsResponseInnerQueryIrGroupBy' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
225 226 227 228 229 230 231 232 233 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir.rb', line 225 def ==(o) return true if self.equal?(o) self.class == o.class && agg == o.agg && metric == o.metric && value_label == o.value_label && filters == o.filters && group_by == o.group_by end |
#eql?(o) ⇒ Boolean
237 238 239 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir.rb', line 237 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
243 244 245 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir.rb', line 243 def hash [agg, metric, value_label, filters, group_by].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir.rb', line 115 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @agg.nil? invalid_properties.push('invalid value for "agg", agg cannot be nil.') end if @metric.nil? invalid_properties.push('invalid value for "metric", metric cannot be nil.') end if @metric.to_s.length > 128 invalid_properties.push('invalid value for "metric", the character length must be smaller than or equal to 128.') end if @metric.to_s.length < 1 invalid_properties.push('invalid value for "metric", the character length must be greater than or equal to 1.') end if !@value_label.nil? && @value_label.to_s.length > 128 invalid_properties.push('invalid value for "value_label", the character length must be smaller than or equal to 128.') end if !@value_label.nil? && @value_label.to_s.length < 1 invalid_properties.push('invalid value for "value_label", the character length must be greater than or equal to 1.') end if !@filters.nil? && @filters.length > 16 invalid_properties.push('invalid value for "filters", number of items must be less than or equal to 16.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir.rb', line 272 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/shipeasy_admin/models/list_metrics_response_inner_query_ir.rb', line 151 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @agg.nil? return false if @metric.nil? return false if @metric.to_s.length > 128 return false if @metric.to_s.length < 1 return false if !@value_label.nil? && @value_label.to_s.length > 128 return false if !@value_label.nil? && @value_label.to_s.length < 1 return false if !@filters.nil? && @filters.length > 16 true end |