Class: Shipeasy::Admin::Generated::PushI18nKeysResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Shipeasy::Admin::Generated::PushI18nKeysResponse
- Defined in:
- lib/shipeasy_admin/models/push_i18n_keys_response.rb
Overview
Result of an insert-only key push.
Instance Attribute Summary collapse
-
#added ⇒ Object
Key names that were newly inserted.
-
#chunk ⇒ Object
The chunk the keys were filed under.
-
#pushed_count ⇒ Object
Number of keys inserted (==
added.length). -
#skipped ⇒ Object
Key names that already existed and were left untouched.
-
#skipped_count ⇒ Object
Number of keys skipped (==
skipped.length).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PushI18nKeysResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PushI18nKeysResponse
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/shipeasy_admin/models/push_i18n_keys_response.rb', line 74 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::PushI18nKeysResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::PushI18nKeysResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'added') if (value = attributes[:'added']).is_a?(Array) self.added = value end else self.added = nil end if attributes.key?(:'skipped') if (value = attributes[:'skipped']).is_a?(Array) self.skipped = value end else self.skipped = nil end if attributes.key?(:'pushed_count') self.pushed_count = attributes[:'pushed_count'] else self.pushed_count = nil end if attributes.key?(:'skipped_count') self.skipped_count = attributes[:'skipped_count'] else self.skipped_count = nil end if attributes.key?(:'chunk') self.chunk = attributes[:'chunk'] end end |
Instance Attribute Details
#added ⇒ Object
Key names that were newly inserted.
20 21 22 |
# File 'lib/shipeasy_admin/models/push_i18n_keys_response.rb', line 20 def added @added end |
#chunk ⇒ Object
The chunk the keys were filed under.
32 33 34 |
# File 'lib/shipeasy_admin/models/push_i18n_keys_response.rb', line 32 def chunk @chunk end |
#pushed_count ⇒ Object
Number of keys inserted (== added.length).
26 27 28 |
# File 'lib/shipeasy_admin/models/push_i18n_keys_response.rb', line 26 def pushed_count @pushed_count end |
#skipped ⇒ Object
Key names that already existed and were left untouched.
23 24 25 |
# File 'lib/shipeasy_admin/models/push_i18n_keys_response.rb', line 23 def skipped @skipped end |
#skipped_count ⇒ Object
Number of keys skipped (== skipped.length).
29 30 31 |
# File 'lib/shipeasy_admin/models/push_i18n_keys_response.rb', line 29 def skipped_count @skipped_count end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
46 47 48 |
# File 'lib/shipeasy_admin/models/push_i18n_keys_response.rb', line 46 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
51 52 53 |
# File 'lib/shipeasy_admin/models/push_i18n_keys_response.rb', line 51 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 |
# File 'lib/shipeasy_admin/models/push_i18n_keys_response.rb', line 35 def self.attribute_map { :'added' => :'added', :'skipped' => :'skipped', :'pushed_count' => :'pushed_count', :'skipped_count' => :'skipped_count', :'chunk' => :'chunk' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/shipeasy_admin/models/push_i18n_keys_response.rb', line 223 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
67 68 69 70 |
# File 'lib/shipeasy_admin/models/push_i18n_keys_response.rb', line 67 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 |
# File 'lib/shipeasy_admin/models/push_i18n_keys_response.rb', line 56 def self.openapi_types { :'added' => :'Array<String>', :'skipped' => :'Array<String>', :'pushed_count' => :'Float', :'skipped_count' => :'Float', :'chunk' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
198 199 200 201 202 203 204 205 206 |
# File 'lib/shipeasy_admin/models/push_i18n_keys_response.rb', line 198 def ==(o) return true if self.equal?(o) self.class == o.class && added == o.added && skipped == o.skipped && pushed_count == o.pushed_count && skipped_count == o.skipped_count && chunk == o.chunk end |
#eql?(o) ⇒ Boolean
210 211 212 |
# File 'lib/shipeasy_admin/models/push_i18n_keys_response.rb', line 210 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
216 217 218 |
# File 'lib/shipeasy_admin/models/push_i18n_keys_response.rb', line 216 def hash [added, skipped, pushed_count, skipped_count, chunk].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/shipeasy_admin/models/push_i18n_keys_response.rb', line 123 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @added.nil? invalid_properties.push('invalid value for "added", added cannot be nil.') end if @skipped.nil? invalid_properties.push('invalid value for "skipped", skipped cannot be nil.') end if @pushed_count.nil? invalid_properties.push('invalid value for "pushed_count", pushed_count cannot be nil.') end if @skipped_count.nil? invalid_properties.push('invalid value for "skipped_count", skipped_count cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/shipeasy_admin/models/push_i18n_keys_response.rb', line 245 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
147 148 149 150 151 152 153 154 |
# File 'lib/shipeasy_admin/models/push_i18n_keys_response.rb', line 147 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @added.nil? return false if @skipped.nil? return false if @pushed_count.nil? return false if @skipped_count.nil? true end |