Class: Shipeasy::Admin::Generated::ToggleKillswitchResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Shipeasy::Admin::Generated::ToggleKillswitchResponse
- Defined in:
- lib/shipeasy_admin/models/toggle_killswitch_response.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#env ⇒ Object
Returns the value of attribute env.
-
#id ⇒ Object
Resolved killswitch id.
-
#previous ⇒ Object
The value that was in effect before this call.
-
#published ⇒ Object
Returns the value of attribute published.
-
#switch_key ⇒ Object
The sub-switch that was flipped, or
nullwhen the flatvaluewas. -
#value ⇒ Object
The value now in effect on
env. -
#version ⇒ Object
Newly published version on
env.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ToggleKillswitchResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ToggleKillswitchResponse
Initializes the object
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/shipeasy_admin/models/toggle_killswitch_response.rb', line 104 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::ToggleKillswitchResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::ToggleKillswitchResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'env') self.env = attributes[:'env'] else self.env = nil end if attributes.key?(:'switch_key') self.switch_key = attributes[:'switch_key'] else self.switch_key = nil end if attributes.key?(:'previous') self.previous = attributes[:'previous'] else self.previous = nil end if attributes.key?(:'value') self.value = attributes[:'value'] else self.value = nil end if attributes.key?(:'version') self.version = attributes[:'version'] else self.version = nil end if attributes.key?(:'published') self.published = attributes[:'published'] else self.published = nil end end |
Instance Attribute Details
#env ⇒ Object
Returns the value of attribute env.
21 22 23 |
# File 'lib/shipeasy_admin/models/toggle_killswitch_response.rb', line 21 def env @env end |
#id ⇒ Object
Resolved killswitch id.
19 20 21 |
# File 'lib/shipeasy_admin/models/toggle_killswitch_response.rb', line 19 def id @id end |
#previous ⇒ Object
The value that was in effect before this call. Equal to value when an idempotent value matched what was already stored.
27 28 29 |
# File 'lib/shipeasy_admin/models/toggle_killswitch_response.rb', line 27 def previous @previous end |
#published ⇒ Object
Returns the value of attribute published.
35 36 37 |
# File 'lib/shipeasy_admin/models/toggle_killswitch_response.rb', line 35 def published @published end |
#switch_key ⇒ Object
The sub-switch that was flipped, or null when the flat value was.
24 25 26 |
# File 'lib/shipeasy_admin/models/toggle_killswitch_response.rb', line 24 def switch_key @switch_key end |
#value ⇒ Object
The value now in effect on env.
30 31 32 |
# File 'lib/shipeasy_admin/models/toggle_killswitch_response.rb', line 30 def value @value end |
#version ⇒ Object
Newly published version on env.
33 34 35 |
# File 'lib/shipeasy_admin/models/toggle_killswitch_response.rb', line 33 def version @version end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
73 74 75 |
# File 'lib/shipeasy_admin/models/toggle_killswitch_response.rb', line 73 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
78 79 80 |
# File 'lib/shipeasy_admin/models/toggle_killswitch_response.rb', line 78 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/shipeasy_admin/models/toggle_killswitch_response.rb', line 60 def self.attribute_map { :'id' => :'id', :'env' => :'env', :'switch_key' => :'switchKey', :'previous' => :'previous', :'value' => :'value', :'version' => :'version', :'published' => :'published' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 |
# File 'lib/shipeasy_admin/models/toggle_killswitch_response.rb', line 339 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
96 97 98 99 100 |
# File 'lib/shipeasy_admin/models/toggle_killswitch_response.rb', line 96 def self.openapi_nullable Set.new([ :'switch_key', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/shipeasy_admin/models/toggle_killswitch_response.rb', line 83 def self.openapi_types { :'id' => :'String', :'env' => :'Env', :'switch_key' => :'String', :'previous' => :'Boolean', :'value' => :'Boolean', :'version' => :'Integer', :'published' => :'KillswitchValue' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/shipeasy_admin/models/toggle_killswitch_response.rb', line 312 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && env == o.env && switch_key == o.switch_key && previous == o.previous && value == o.value && version == o.version && published == o.published end |
#eql?(o) ⇒ Boolean
326 327 328 |
# File 'lib/shipeasy_admin/models/toggle_killswitch_response.rb', line 326 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
332 333 334 |
# File 'lib/shipeasy_admin/models/toggle_killswitch_response.rb', line 332 def hash [id, env, switch_key, previous, value, version, published].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/shipeasy_admin/models/toggle_killswitch_response.rb', line 163 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @env.nil? invalid_properties.push('invalid value for "env", env cannot be nil.') end if @switch_key.to_s.length > 64 invalid_properties.push('invalid value for "switch_key", the character length must be smaller than or equal to 64.') end pattern = Regexp.new(/^[a-z0-9](?:[a-z0-9_-]*[a-z0-9])?$/) if @switch_key !~ pattern invalid_properties.push("invalid value for \"switch_key\", must conform to the pattern #{pattern}.") end if @previous.nil? invalid_properties.push('invalid value for "previous", previous cannot be nil.') end if @value.nil? invalid_properties.push('invalid value for "value", value cannot be nil.') end if @version.nil? invalid_properties.push('invalid value for "version", version cannot be nil.') end if @version > 9007199254740991 invalid_properties.push('invalid value for "version", must be smaller than or equal to 9007199254740991.') end if @version < -9007199254740991 invalid_properties.push('invalid value for "version", must be greater than or equal to -9007199254740991.') end if @published.nil? invalid_properties.push('invalid value for "published", published cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
361 362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/shipeasy_admin/models/toggle_killswitch_response.rb', line 361 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/shipeasy_admin/models/toggle_killswitch_response.rb', line 212 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @env.nil? return false if @switch_key.to_s.length > 64 return false if @switch_key !~ Regexp.new(/^[a-z0-9](?:[a-z0-9_-]*[a-z0-9])?$/) return false if @previous.nil? return false if @value.nil? return false if @version.nil? return false if @version > 9007199254740991 return false if @version < -9007199254740991 return false if @published.nil? true end |