Class: Shipeasy::Admin::Generated::UpdateOpsItemRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Shipeasy::Admin::Generated::UpdateOpsItemRequest
- Defined in:
- lib/shipeasy_admin/models/update_ops_item_request.rb
Overview
Body for PATCH /api/admin/ops/{handle}. Pass at least one of status / priority.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#priority ⇒ Object
New triage priority.
-
#status ⇒ Object
New lifecycle status.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpdateOpsItemRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpdateOpsItemRequest
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/shipeasy_admin/models/update_ops_item_request.rb', line 81 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::UpdateOpsItemRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::UpdateOpsItemRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'priority') self.priority = attributes[:'priority'] end end |
Instance Attribute Details
#priority ⇒ Object
New triage priority.
23 24 25 |
# File 'lib/shipeasy_admin/models/update_ops_item_request.rb', line 23 def priority @priority end |
#status ⇒ Object
New lifecycle status.
20 21 22 |
# File 'lib/shipeasy_admin/models/update_ops_item_request.rb', line 20 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
56 57 58 |
# File 'lib/shipeasy_admin/models/update_ops_item_request.rb', line 56 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
61 62 63 |
# File 'lib/shipeasy_admin/models/update_ops_item_request.rb', line 61 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
48 49 50 51 52 53 |
# File 'lib/shipeasy_admin/models/update_ops_item_request.rb', line 48 def self.attribute_map { :'status' => :'status', :'priority' => :'priority' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/shipeasy_admin/models/update_ops_item_request.rb', line 167 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
74 75 76 77 |
# File 'lib/shipeasy_admin/models/update_ops_item_request.rb', line 74 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 |
# File 'lib/shipeasy_admin/models/update_ops_item_request.rb', line 66 def self.openapi_types { :'status' => :'String', :'priority' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
145 146 147 148 149 150 |
# File 'lib/shipeasy_admin/models/update_ops_item_request.rb', line 145 def ==(o) return true if self.equal?(o) self.class == o.class && status == o.status && priority == o.priority end |
#eql?(o) ⇒ Boolean
154 155 156 |
# File 'lib/shipeasy_admin/models/update_ops_item_request.rb', line 154 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
160 161 162 |
# File 'lib/shipeasy_admin/models/update_ops_item_request.rb', line 160 def hash [status, priority].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
106 107 108 109 110 |
# File 'lib/shipeasy_admin/models/update_ops_item_request.rb', line 106 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/shipeasy_admin/models/update_ops_item_request.rb', line 189 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
114 115 116 117 118 119 120 121 |
# File 'lib/shipeasy_admin/models/update_ops_item_request.rb', line 114 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["open", "triaged", "in_progress", "ready_for_qa", "resolved", "wont_fix"]) return false unless status_validator.valid?(@status) priority_validator = EnumAttributeValidator.new('String', ["nice_to_have", "medium", "high", "critical"]) return false unless priority_validator.valid?(@priority) true end |