Class: Shipeasy::Admin::Generated::UpsertProjectRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Shipeasy::Admin::Generated::UpsertProjectRequest
- Defined in:
- lib/shipeasy_admin/models/upsert_project_request.rb
Overview
Body for POST /api/admin/projects/upsert. Only domain is required; the owner is resolved from the caller's session.
Instance Attribute Summary collapse
-
#domain ⇒ Object
Hostname-like project identifier (e.g.
acme.com). -
#name ⇒ Object
Human-readable project name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ UpsertProjectRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ UpsertProjectRequest
Initializes the object
59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/shipeasy_admin/models/upsert_project_request.rb', line 59 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Shipeasy::Admin::Generated::UpsertProjectRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Shipeasy::Admin::Generated::UpsertProjectRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'domain') self.domain = attributes[:'domain'] else self.domain = nil end if attributes.key?(:'name') self.name = attributes[:'name'] end end |
Instance Attribute Details
#domain ⇒ Object
Hostname-like project identifier (e.g. acme.com). Use * to allow any origin. The project is keyed by (owner_email, domain), so a second call with the same domain returns the existing project.
20 21 22 |
# File 'lib/shipeasy_admin/models/upsert_project_request.rb', line 20 def domain @domain end |
#name ⇒ Object
Human-readable project name. Defaults to the domain on first create.
23 24 25 |
# File 'lib/shipeasy_admin/models/upsert_project_request.rb', line 23 def name @name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
34 35 36 |
# File 'lib/shipeasy_admin/models/upsert_project_request.rb', line 34 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
39 40 41 |
# File 'lib/shipeasy_admin/models/upsert_project_request.rb', line 39 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 |
# File 'lib/shipeasy_admin/models/upsert_project_request.rb', line 26 def self.attribute_map { :'domain' => :'domain', :'name' => :'name' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/shipeasy_admin/models/upsert_project_request.rb', line 184 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
52 53 54 55 |
# File 'lib/shipeasy_admin/models/upsert_project_request.rb', line 52 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 |
# File 'lib/shipeasy_admin/models/upsert_project_request.rb', line 44 def self.openapi_types { :'domain' => :'String', :'name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
162 163 164 165 166 167 |
# File 'lib/shipeasy_admin/models/upsert_project_request.rb', line 162 def ==(o) return true if self.equal?(o) self.class == o.class && domain == o.domain && name == o.name end |
#eql?(o) ⇒ Boolean
171 172 173 |
# File 'lib/shipeasy_admin/models/upsert_project_request.rb', line 171 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
177 178 179 |
# File 'lib/shipeasy_admin/models/upsert_project_request.rb', line 177 def hash [domain, name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/shipeasy_admin/models/upsert_project_request.rb', line 86 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @domain.nil? invalid_properties.push('invalid value for "domain", domain cannot be nil.') end if @domain.to_s.length > 2048 invalid_properties.push('invalid value for "domain", the character length must be smaller than or equal to 2048.') end if @domain.to_s.length < 1 invalid_properties.push('invalid value for "domain", the character length must be greater than or equal to 1.') end if !@name.nil? && @name.to_s.length > 100 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.') end if !@name.nil? && @name.to_s.length < 1 invalid_properties.push('invalid value for "name", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/shipeasy_admin/models/upsert_project_request.rb', line 206 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
114 115 116 117 118 119 120 121 122 |
# File 'lib/shipeasy_admin/models/upsert_project_request.rb', line 114 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @domain.nil? return false if @domain.to_s.length > 2048 return false if @domain.to_s.length < 1 return false if !@name.nil? && @name.to_s.length > 100 return false if !@name.nil? && @name.to_s.length < 1 true end |